@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: being.cpp 4048 2008-04-07 16:54:28Z b_lindeijer $
+ *  $Id: being.cpp 4301 2008-05-28 16:06:48Z peaveydk $
  */
 #include "being.h"
 
@@ -72,7 +72,7 @@ Being::Being(int id, int job, Map *map):
     {
         // Load the emotion set
         ResourceManager *rm = ResourceManager::getInstance();
-        emotionSet = rm->getImageSet("graphics/sprites/emotions.png", 30, 32);
+        emotionSet = rm->getImageSet("graphics/gui/emotions.png", 30, 32);
         if (!emotionSet) logger->error("Unable to load emotions!");
     }
 
@@ -300,14 +300,14 @@ Being::getSpriteDirection() const
     {
         dir = DIRECTION_UP;
     }
-    else if (mDirection & RIGHT)
-    {
-        dir = DIRECTION_RIGHT;
-    }
     else if (mDirection & DOWN)
     {
         dir = DIRECTION_DOWN;
     }
+    else if (mDirection & RIGHT)
+    {
+        dir = DIRECTION_RIGHT;
+    }
     else {
         dir = DIRECTION_LEFT;
     }
@@ -422,7 +422,7 @@ Being::drawEmotion(Graphics *graphics, int offsetX, int offsetY)
     const int py = mPy + offsetY - 60;
     const int emotionIndex = mEmotion - 1;
 
-    if (emotionIndex >= 0 && emotionIndex < emotionSet->size())
+    if (emotionIndex >= 0 && emotionIndex < (int) emotionSet->size())
         graphics->drawImage(emotionSet->get(emotionIndex), px, py);
 }
 
