@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: being.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: being.h 4321 2008-06-02 11:42:26Z b_lindeijer $
  */
 
 #ifndef _TMW_BEING_H
@@ -37,6 +37,8 @@
 #define NR_HAIR_STYLES 8
 #define NR_HAIR_COLORS 10
 
+#define FIRST_IGNORE_EMOTE 14
+
 class AnimatedSprite;
 class Equipment;
 class ItemInfo;
@@ -94,6 +96,7 @@ class Being : public Sprite
             HAIR_SPRITE,
             HAT_SPRITE,
             WEAPON_SPRITE,
+            SHIELD_SPRITE,
             VECTOREND_SPRITE
         };
 
@@ -356,6 +359,8 @@ class Being : public Sprite
          */
         void controlParticle(Particle *particle);
 
+        void setEmote(Uint8 emotion, Uint8 emote_time) { mEmotion = emotion; mEmotionTime = emote_time; }
+
         const std::auto_ptr<Equipment> mEquipment;
 
     protected:
