@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: beingmanager.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: beingmanager.cpp 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -75,7 +75,7 @@ Being* BeingManager::createBeing(Uint32 id, Uint16 job)
 
     if (job < 10)
         being = new Player(id, job, mMap);
-    else if (job >= 100 & job < 200)
+    else if (job >= 100 && job < 200)
         being = new NPC(id, job, mMap, mNetwork);
     else if (job >= 1000 && job < 1200)
         being = new Monster(id, job, mMap);
@@ -124,6 +124,43 @@ Being* BeingManager::findBeing(Uint16 x, Uint16 y, Being::Type type)
     return (i == mBeings.end()) ? NULL : *i;
 }
 
+Being* BeingManager::findBeingByPixel(Uint16 x, Uint16 y)
+{
+    BeingIterator itr = mBeings.begin();
+    BeingIterator itr_end = mBeings.end();
+
+    for (; itr != itr_end; ++itr)
+    {
+        Being *being = (*itr);
+        if ((being->mAction != Being::DEAD) &&
+            (being != player_node) &&
+            (being->getPixelX() <= x) &&
+            (being->getPixelX() + being->getWidth() >= x) &&
+            (being->getPixelY() <= y) &&
+            (being->getPixelY() + being->getHeight() >= y))
+        {
+            return being;
+        }
+    }
+
+    return NULL;
+}
+
+Being* BeingManager::findBeingByName(std::string name, Being::Type type)
+{
+    for (BeingIterator i = mBeings.begin(); i != mBeings.end(); i++)
+    {
+        Being *being = (*i);
+        if (being->getName() == name
+            && (type == Being::UNKNOWN
+                || type == being->getType()))
+            return being;
+    }
+    return NULL;
+}
+
+
+
 Beings& BeingManager::getAll()
 {
     return mBeings;
