@@ -18,13 +18,14 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: floor_item.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: floor_item.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_FLOORITEM_H_
 #define _TMW_FLOORITEM_H_
 
 #include "graphics.h"
+#include "item.h"
 #include "map.h"
 #include "sprite.h"
 #include "resources/image.h"
@@ -59,7 +60,7 @@ class FloorItem : public Sprite
          * Returns the item id.
          */
         unsigned int
-        getItemId() const { return mItemId; }
+        getItemId() const { return mItem->getId(); }
 
         /**
          * Returns the x coordinate.
@@ -89,16 +90,15 @@ class FloorItem : public Sprite
         void
         draw(Graphics *graphics, int offsetX, int offsetY) const
         {
-            graphics->drawImage(mImage,
+            graphics->drawImage(mItem->getImage(),
                                 mX * 32 + offsetX,
                                 mY * 32 + offsetY);
         }
 
     private:
         unsigned int mId;
-        unsigned int mItemId;
         unsigned short mX, mY;
-        Image *mImage;
+        Item *mItem;
         Sprites::iterator mSpriteIterator;
         Map *mMap;
 };
