@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: game.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: game.cpp 4452 2008-07-27 16:28:37Z b_lindeijer $
  */
 
 #include "game.h"
@@ -36,13 +36,14 @@
 #include "engine.h"
 #include "flooritemmanager.h"
 #include "graphics.h"
-//#include "itemshortcut.h"
+#include "itemshortcut.h"
 #include "joystick.h"
 #include "keyboardconfig.h"
 #include "localplayer.h"
 #include "log.h"
 #include "npc.h"
 #include "particle.h"
+#include "player_relations.h"
 
 #include "gui/buy.h"
 #include "gui/buysell.h"
@@ -54,7 +55,7 @@
 #include "gui/gui.h"
 #include "gui/help.h"
 #include "gui/inventorywindow.h"
-//#include "gui/itemshortcutwindow.h"
+#include "gui/itemshortcutwindow.h"
 #include "gui/menuwindow.h"
 #include "gui/minimap.h"
 #include "gui/ministatus.h"
@@ -120,7 +121,7 @@ TradeWindow *tradeWindow;
 //BuddyWindow *buddyWindow;
 HelpWindow *helpWindow;
 DebugWindow *debugWindow;
-//ItemShortcutWindow *itemShortcutWindow;
+ItemShortcutWindow *itemShortcutWindow;
 
 BeingManager *beingManager = NULL;
 FloorItemManager *floorItemManager = NULL;
@@ -201,7 +202,7 @@ void createGuiWindows(Network *network)
     //buddyWindow = new BuddyWindow();
     helpWindow = new HelpWindow();
     debugWindow = new DebugWindow();
-    //itemShortcutWindow = new ItemShortcutWindow();
+    itemShortcutWindow = new ItemShortcutWindow();
 
     // Initialize window positions
     //chargeDialog->setPosition(
@@ -211,10 +212,17 @@ void createGuiWindows(Network *network)
     //buddyWindow->setPosition(10, minimap->getHeight() + 30);
 
     // Set initial window visibility
-    chatWindow->setVisible(true);
-    miniStatusWindow->setVisible(true);
-    menuWindow->setVisible(true);
-    //itemShortcutWindow->setVisible(true);
+    chatWindow->setVisible((bool) config.getValue(
+        chatWindow->getWindowName() + "Visible", true));
+    miniStatusWindow->setVisible((bool) config.getValue(
+        miniStatusWindow->getWindowName() + "Visible",
+        true));
+    buyDialog->setVisible(false);
+    sellDialog->setVisible(false);
+    menuWindow->setVisible((bool) config.getValue(
+        menuWindow->getWindowName() + "Visible", true));
+    itemShortcutWindow->setVisible((bool) config.getValue(
+        itemShortcutWindow->getWindowName() + "Visible", true));
 
     if (config.getValue("logToChat", 0))
     {
@@ -247,7 +255,7 @@ void destroyGuiWindows()
     //delete buddyWindow;
     delete helpWindow;
     delete debugWindow;
-    //delete itemShortcutWindow;
+    delete itemShortcutWindow;
 }
 
 Game::Game(Network *network):
@@ -461,8 +469,104 @@ void Game::handleInput()
                 keyboard.setNewKeyIndex(keyboard.KEY_NO_VALUE);
                 return;
             }
+            // Keys pressed together with Alt/Meta
+            // Emotions and some internal gui windows
+            #ifndef __APPLE__
+            if (event.key.keysym.mod & KMOD_LALT)
+            #else
+            if (event.key.keysym.mod & KMOD_LMETA)
+            #endif
+            {
+                switch (event.key.keysym.sym)
+                {
+                    case SDLK_p:
+                        // Screenshot (picture, hence the p)
+                        {
+                            SDL_Surface *screenshot = graphics->getScreenshot();
+                            if (!saveScreenshot(screenshot))
+                            {
+                                logger->log("Error: could not save Screenshot.");
+                            }
+                            SDL_FreeSurface(screenshot);
+                        }
+                        used = true;
+                        break;
+
+                    default:
+                        break;
+
+                    case SDLK_f:
+                        // Find path to mouse (debug purpose)
+                        viewport->toggleDebugPath();
+                        used = true;
+                        break;
+
+                    case SDLK_t:
+                        // Toggle accepting of incoming trade requests
+                        {
+                            unsigned int deflt = player_relations.getDefault();
+                            if (deflt & PlayerRelation::TRADE) {
+                                chatWindow->chatLog("Ignoring incoming trade requests", BY_SERVER);
+                                deflt &= ~PlayerRelation::TRADE;
+                            } else {
+                                chatWindow->chatLog("Accepting incoming trade requests", BY_SERVER);
+                                deflt |= PlayerRelation::TRADE;
+                            }
+
+                            player_relations.setDefault(deflt);
+                        }
+                        used = true;
+                        break;
+                }
+            }
+
+            // Smilie
+            if (keyboard.isKeyActive(keyboard.KEY_SMILIE))
+            {
+                // Emotions
+                Uint8 emotion;
+                switch (event.key.keysym.sym)
+                {
+                    case SDLK_1: emotion = 1; break;
+                    case SDLK_2: emotion = 2; break;
+                    case SDLK_3: emotion = 3; break;
+                    case SDLK_4: emotion = 4; break;
+                    case SDLK_5: emotion = 5; break;
+                    case SDLK_6: emotion = 6; break;
+                    case SDLK_7: emotion = 7; break;
+                    case SDLK_8: emotion = 8; break;
+                    case SDLK_9: emotion = 9; break;
+                    case SDLK_0: emotion = 10; break;
+                    case SDLK_MINUS: emotion = 11; break;
+                    case SDLK_EQUALS: emotion = 12; break;
+                    default: emotion = 0; break;
+                }
+
+                if (emotion)
+                {
+                    player_node->emote(emotion);
+                    used = true;
+                    return;
+                }
+            }
             switch (event.key.keysym.sym)
             {
+                case SDLK_PAGEUP:
+                    if (chatWindow->isVisible())
+                    {
+                        chatWindow->scroll(-DEFAULT_CHAT_WINDOW_SCROLL);
+                        used = true;
+                    }
+                    break;
+
+                case SDLK_PAGEDOWN:
+                    if (chatWindow->isVisible())
+                    {
+                        chatWindow->scroll(DEFAULT_CHAT_WINDOW_SCROLL);
+                        used = true;
+                    }
+                    break;
+
                 case SDLK_F1:
                     // In-game Help
                     if (helpWindow->isVisible())
@@ -483,14 +587,14 @@ void Game::handleInput()
                 case SDLK_F5: requestedWindow = skillDialog; break;
                 case SDLK_F6: requestedWindow = minimap; break;
                 case SDLK_F7: requestedWindow = chatWindow; break;
-                //case SDLK_F8: requestedWindow = buddyWindow; break;
+                case SDLK_F8: requestedWindow = itemShortcutWindow; break;
                 case SDLK_F9: requestedWindow = setupWindow; break;
                 case SDLK_F10: requestedWindow = debugWindow; break;
                 //case SDLK_F11: requestedWindow = newSkillWindow; break;
 
                 case SDLK_RETURN:
                     // Input chat window
-                    if (chatWindow->isFocused() ||
+                    if (chatWindow->isInputFocused() ||
                         deathNotice != NULL ||
                         weightNotice != NULL)
                     {
@@ -536,23 +640,20 @@ void Game::handleInput()
                 default:
                     break;
             }
-
-            if (keyboard.isEnabled() && !chatWindow->isFocused())
+            if (keyboard.isEnabled() && !chatWindow->isInputFocused())
             {
                 const int tKey = keyboard.getKeyIndex(event.key.keysym.sym);
                 // Checks if any item shortcut is pressed.
-                /*
                 for (int i = KeyboardConfig::KEY_SHORTCUT_0;
                     i <= KeyboardConfig::KEY_SHORTCUT_9;
                     i++)
                 {
-                    if (tKey == i) {
+                    if (tKey == i && !used) {
                         itemShortcut->useItem(
                                 i - KeyboardConfig::KEY_SHORTCUT_0);
                         break;
                     }
                 }
-                */
                 switch (tKey) {
                     case KeyboardConfig::KEY_PICKUP:
                         {
@@ -589,7 +690,7 @@ void Game::handleInput()
                         break;
                     case KeyboardConfig::KEY_HIDE_WINDOWS:
                          // Hide certain windows
-                        if (!chatWindow->isFocused())
+                        if (!chatWindow->isInputFocused())
                         {
                             statusWindow->setVisible(false);
                             inventoryWindow->setVisible(false);
@@ -613,71 +714,6 @@ void Game::handleInput()
                 used = true;
             }
 
-            // Keys pressed together with Alt/Meta
-            // Emotions and some internal gui windows
-            if (event.key.keysym.mod & KMOD_ALT)
-            {
-                switch (event.key.keysym.sym)
-                {
-                    case SDLK_p:
-                        // Screenshot (picture, hence the p)
-                        {
-                            SDL_Surface *screenshot = graphics->getScreenshot();
-                            if (!saveScreenshot(screenshot))
-                            {
-                                logger->log("Error: could not save Screenshot.");
-                            }
-                            SDL_FreeSurface(screenshot);
-                        }
-                        used = true;
-                        break;
-
-                    default:
-                        break;
-
-                    case SDLK_f:
-                        // Find path to mouse (debug purpose)
-                        viewport->toggleDebugPath();
-                        used = true;
-                        break;
-
-                    case SDLK_t:
-                        // Toggle accepting of incoming trade requests
-                        {
-                            TradeHandler *th = static_cast<TradeHandler*>(
-                                    mTradeHandler.get());
-                            th->setAcceptTradeRequests(
-                                    !th->acceptTradeRequests());
-                        }
-                        used = true;
-                        break;
-                }
-
-                // Emotions
-                Uint8 emotion;
-                switch (event.key.keysym.sym)
-                {
-                    case SDLK_1: emotion = 1; break;
-                    case SDLK_2: emotion = 2; break;
-                    case SDLK_3: emotion = 3; break;
-                    case SDLK_4: emotion = 4; break;
-                    case SDLK_5: emotion = 5; break;
-                    case SDLK_6: emotion = 6; break;
-                    case SDLK_7: emotion = 7; break;
-                    case SDLK_8: emotion = 8; break;
-                    case SDLK_9: emotion = 9; break;
-                    case SDLK_0: emotion = 10; break;
-                    case SDLK_MINUS: emotion = 11; break;
-                    case SDLK_EQUALS: emotion = 12; break;
-                    default: emotion = 0; break;
-                }
-
-                if (emotion)
-                {
-                    player_node->emote(emotion);
-                    used = true;
-                }
-            }
         }
 
         // Quit event
@@ -709,7 +745,7 @@ void Game::handleInput()
     // Moving player around
     if (player_node->mAction != Being::DEAD &&
         current_npc == 0 &&
-        !chatWindow->isFocused())
+        !chatWindow->isInputFocused())
     {
         // Get the state of the keyboard keys
         keyboard.refreshActiveKeys();
@@ -744,8 +780,8 @@ void Game::handleInput()
         player_node->setWalkingDir(direction);
 
         // Attacking monsters
-        if ( keyboard.isKeyActive(keyboard.KEY_ATTACK) ||
-                joystick && joystick->buttonPressed(0))
+        if (keyboard.isKeyActive(keyboard.KEY_ATTACK) ||
+                (joystick && joystick->buttonPressed(0)))
         {
             Being *target = NULL;
             bool newTarget = keyboard.isKeyActive(keyboard.KEY_TARGET);
@@ -774,12 +810,11 @@ void Game::handleInput()
             player_node->attack(target, newTarget);
         }
 
-        // Target the nearest player if 'q' is pressed
-        if ( keyboard.isKeyActive(keyboard.KEY_TARGET_PLAYER) )
-        //if (keys[SDLK_q])
+        // Target the nearest player
+        if (keyboard.isKeyActive(keyboard.KEY_TARGET_PLAYER))
         {
-            Being *target =
-                beingManager->findNearestLivingBeing(player_node, 20, Being::PLAYER);
+            Being *target = beingManager->findNearestLivingBeing(
+                    player_node, 20, Being::PLAYER);
 
             if (target)
             {
@@ -787,9 +822,9 @@ void Game::handleInput()
             }
         }
 
-        // Target the nearest monster if 'a' pressed
-        if ( keyboard.isKeyActive(keyboard.KEY_TARGET_CLOSEST) )
-        //if (keys[SDLK_a])
+        // Target the nearest monster
+        if (keyboard.isKeyActive(keyboard.KEY_TARGET_CLOSEST)
+                || (joystick && joystick->buttonPressed(3)))
         {
             Being *target =
                 beingManager->findNearestLivingBeing(x, y, 20, Being::MONSTER);
