@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: buy.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: buy.cpp 4449 2008-07-24 17:04:42Z umperio $
  */
 
 #include "buy.h"
@@ -33,8 +33,6 @@
 
 #include "../npc.h"
 
-#include "../resources/itemdb.h"
-
 #include "../net/messageout.h"
 #include "../net/protocol.h"
 
@@ -44,6 +42,7 @@ BuyDialog::BuyDialog(Network *network):
     Window("Buy"), mNetwork(network),
     mMoney(0), mAmountItems(0), mMaxItems(0)
 {
+    setWindowName("Buy");
     setResizable(true);
     setMinWidth(260);
     setMinHeight(230);
@@ -90,7 +89,6 @@ BuyDialog::BuyDialog(Network *network):
     add(mItemDescLabel);
     add(mItemEffectLabel);
 
-    addWindowListener(this);
     loadWindowState();
     setLocationRelativeTo(getParent());
 }
@@ -171,22 +169,22 @@ void BuyDialog::action(const gcn::ActionEvent &event)
         outMsg.writeInt16(CMSG_NPC_BUY_REQUEST);
         outMsg.writeInt16(8);
         outMsg.writeInt16(mAmountItems);
-        outMsg.writeInt16(mShopItems->at(selectedItem).id);
+        outMsg.writeInt16(mShopItems->at(selectedItem)->getId());
+
+        // Update money and adjust the max number of items that can be bought
+        mMaxItems -= mAmountItems;
+        setMoney(mMoney -
+                mAmountItems * mShopItems->at(selectedItem)->getPrice());
 
         // Reset selection
         mAmountItems = 1;
         mSlider->setValue(1);
         mSlider->gcn::Slider::setScale(1, mMaxItems);
-
-        // Update money and adjust the max number of items that can be bought
-        mMaxItems -= mAmountItems;
-        setMoney(mMoney - mAmountItems * mShopItems->at(selectedItem).price);
     }
 }
 
-void BuyDialog::selectionChanged(const SelectionEvent &event)
+void BuyDialog::valueChanged(const gcn::SelectionEvent &event)
 {
-
     // Reset amount of items and update labels
     mAmountItems = 1;
     mSlider->setValue(1);
@@ -195,11 +193,13 @@ void BuyDialog::selectionChanged(const SelectionEvent &event)
     mSlider->gcn::Slider::setScale(1, mMaxItems);
 }
 
-void BuyDialog::windowResized(const WindowEvent &event)
+void BuyDialog::widgetResized(const gcn::Event &event)
 {
-    gcn::Rectangle area = getChildrenArea();
-    int width = area.width;
-    int height = area.height;
+    Window::widgetResized(event);
+
+    const gcn::Rectangle &area = getChildrenArea();
+    const int width = area.width;
+    const int height = area.height;
 
     mDecreaseButton->setPosition(8, height - 8 - mDecreaseButton->getHeight());
     mIncreaseButton->setPosition(
@@ -241,25 +241,27 @@ void BuyDialog::windowResized(const WindowEvent &event)
 void
 BuyDialog::updateButtonsAndLabels()
 {
-    int selectedItem = mShopItemList->getSelected();
+    const int selectedItem = mShopItemList->getSelected();
     int price = 0;
 
     if (selectedItem > -1)
     {
-        const ItemInfo &info = ItemDB::get(mShopItems->at(selectedItem).id);
+        const ItemInfo &info = mShopItems->at(selectedItem)->getInfo();
 
         mItemDescLabel->setCaption("Description: " + info.getDescription());
         mItemEffectLabel->setCaption("Effect: " + info.getEffect());
 
+        int itemPrice = mShopItems->at(selectedItem)->getPrice();
+
         // Calculate how many the player can afford
-        mMaxItems = mMoney / mShopItems->at(selectedItem).price;
+        mMaxItems = mMoney / itemPrice;
         if (mAmountItems > mMaxItems)
         {
             mAmountItems = mMaxItems;
         }
 
         // Calculate price of pending purchase
-        price = mAmountItems * mShopItems->at(selectedItem).price;
+        price = mAmountItems * itemPrice;
     }
     else
     {
