@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: chat.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: chat.cpp 4402 2008-07-08 15:16:22Z the_enemy $
  */
 
 #include <algorithm>
@@ -64,7 +64,7 @@ ChatWindow::ChatWindow(Network *network):
     mTextOutput->setMaxRow((int) config.getValue("ChatLogLength", 0));
     mScrollArea = new ScrollArea(mTextOutput);
     mScrollArea->setPosition(
-            mScrollArea->getBorderSize(), mScrollArea->getBorderSize());
+            mScrollArea->getFrameSize(), mScrollArea->getFrameSize());
     mScrollArea->setScrollPolicy(
             gcn::ScrollArea::SHOW_NEVER, gcn::ScrollArea::SHOW_ALWAYS);
     mScrollArea->setOpaque(false);
@@ -84,12 +84,12 @@ ChatWindow::logic()
 
     const gcn::Rectangle area = getChildrenArea();
 
-    mChatInput->setPosition(mChatInput->getBorderSize(),
+    mChatInput->setPosition(mChatInput->getFrameSize(),
                             area.height - mChatInput->getHeight() -
-                                mChatInput->getBorderSize());
-    mChatInput->setWidth(area.width - 2 * mChatInput->getBorderSize());
-    mScrollArea->setWidth(area.width - 2 * mScrollArea->getBorderSize());
-    mScrollArea->setHeight(area.height - 2 * mScrollArea->getBorderSize() -
+                                mChatInput->getFrameSize());
+    mChatInput->setWidth(area.width - 2 * mChatInput->getFrameSize());
+    mScrollArea->setWidth(area.width - 2 * mScrollArea->getFrameSize());
+    mScrollArea->setHeight(area.height - 2 * mScrollArea->getFrameSize() -
             mChatInput->getHeight() - 5);
     mScrollArea->logic();
 }
@@ -243,7 +243,7 @@ ChatWindow::requestChatFocus()
 }
 
 bool
-ChatWindow::isFocused()
+ChatWindow::isInputFocused()
 {
     return mChatInput->isFocused();
 }
@@ -275,12 +275,25 @@ ChatWindow::chatSend(const std::string &nick, std::string msg)
     }
     else if (msg.substr(0, IS_HELP_LENGTH) == IS_HELP)
     {
-        chatLog("-- Help --", BY_SERVER);
-        chatLog("/help : Display this help.", BY_SERVER);
-        chatLog("/announce : Global announcement (GM only)", BY_SERVER);
-        chatLog("/where : Display map name", BY_SERVER);
-        chatLog("/who : Display number of online users", BY_SERVER);
-        chatLog("/clear : Clears this window", BY_SERVER);
+        msg.erase(0, IS_HELP_LENGTH + 1);
+        trim(msg);
+        std::size_t space = msg.find(" ");
+        std::string msg1;
+        if (space == std::string::npos)
+        {
+            msg1 = "";
+        }
+        else
+        {
+            msg1 = msg.substr(space + 1, msg.length());
+            msg = msg.substr(0, space);
+        }
+        if (msg != "" && msg.at(0) == '/')
+        {
+            msg.erase(0, 1);
+        }
+        trim(msg1);
+        help(msg, msg1);
     }
     else if (msg.substr(0, IS_WHERE_LENGTH) == IS_WHERE)
     {
@@ -295,6 +308,36 @@ ChatWindow::chatSend(const std::string &nick, std::string msg)
     {
         mTextOutput->clearRows();
     }
+    else if (msg.substr(0, IS_WHISPER_LENGTH) == IS_WHISPER)
+    {
+        std::string recvnick = "";
+        msg.erase(0, IS_WHISPER_LENGTH + 1);
+
+        if (msg.substr(0,1) == "\"")
+        {
+            const std::string::size_type pos = msg.find('"', 1);
+            if (pos != std::string::npos) {
+                recvnick = msg.substr(1, pos - 1);
+                msg.erase(0, pos + 2);
+            }
+        }
+        else
+        {
+            const std::string::size_type pos = msg.find(" ");
+            if (pos != std::string::npos) {
+                recvnick = msg.substr(0, pos);
+                msg.erase(0, pos + 1);
+            }
+        }
+
+        MessageOut outMsg(mNetwork);
+        outMsg.writeInt16(CMSG_CHAT_WHISPER);
+        outMsg.writeInt16(msg.length() + 28);
+        outMsg.writeString(recvnick, 24);
+        outMsg.writeString(msg, msg.length());
+
+        chatLog("Whispering to " + recvnick + " : " + msg, BY_PLAYER);
+    }
     else
     {
         chatLog("Unknown command", BY_SERVER);
@@ -379,6 +422,19 @@ ChatWindow::const_msg(CHATSKILL act)
     return msg;
 }
 
+void
+ChatWindow::scroll(int amount)
+{
+    if (!isVisible())
+        return;
+
+    int range = mScrollArea->getHeight() / 8 * amount;
+    gcn::Rectangle scr;
+    scr.y = mScrollArea->getVerticalScrollAmount() + range;
+    scr.height = abs(range);
+    mTextOutput->showPart(scr);
+}
+
 void
 ChatWindow::keyPressed(gcn::KeyEvent &event)
 {
@@ -415,11 +471,77 @@ ChatWindow::setInputText(std::string input_str)
 void
 ChatWindow::setVisible(bool isVisible)
 {
-     Window::setVisible(isVisible);
+    Window::setVisible(isVisible);
 
-     /*
-      * For whatever reason, if setVisible is called, the mTmpVisible effect
-      * should be disabled.
-      */
-     mTmpVisible = false;
+    /*
+     * For whatever reason, if setVisible is called, the mTmpVisible effect
+     * should be disabled.
+     */
+
+    mTmpVisible = false;
+}
+
+void ChatWindow::help(const std::string &msg1, const std::string &msg2)
+{
+    chatLog("-- Help --", BY_SERVER);
+    if (msg1 == "")
+    {
+        chatLog("/announce: Global announcement (GM only)", BY_SERVER);
+        chatLog("/clear: Clears this window", BY_SERVER);
+        chatLog("/help: Display this help.", BY_SERVER);
+        chatLog("/where: Display map name", BY_SERVER);
+        chatLog("/whisper <nick> <message>: Sends a private <message>"
+                " to <nick>", BY_SERVER);
+        chatLog("/who: Display number of online users", BY_SERVER);
+        chatLog("For more information, type /help <command>", BY_SERVER);
+        return;
+    }
+    if (msg1 == "announce")
+    {
+        chatLog("Command: /announce <msg>", BY_SERVER);
+        chatLog("*** only available to a GM ***", BY_SERVER);
+        chatLog("This command sends the message <msg> to "
+                "all players currently online.", BY_SERVER);
+        return;
+    }
+    if (msg1 == "clear")
+    {
+        chatLog("Command: /clear", BY_SERVER);
+        chatLog("This command clears the chat log of previous chat.",
+                BY_SERVER);
+        return;
+    }
+    if (msg1 == "help")
+    {
+        chatLog("Command: /help", BY_SERVER);
+        chatLog("This command displays a list of all commands available.",
+                BY_SERVER);
+        chatLog("Command: /help <command>", BY_SERVER);
+        chatLog("This command displays help on <command>.", BY_SERVER);
+        return;
+    }
+    if (msg1 == "where")
+    {
+        chatLog("Command: /where", BY_SERVER);
+        chatLog("This command displays the name of the current map.",
+                BY_SERVER);
+        return;
+    }
+    if (msg1 == "whisper")
+    {
+        chatLog("Command: /whisper <nick> <msg>", BY_SERVER);
+        chatLog("This command sends the message <msg> to <nick.", BY_SERVER);
+        chatLog("If the <nick> has spaces in it, enclose it in "
+                "double quotes (\").", BY_SERVER);
+        return;
+    }
+    if (msg1 == "who")
+    {
+        chatLog("Command: /who", BY_SERVER);
+        chatLog("This command displays the number of players currently "
+                "online.", BY_SERVER);
+        return;
+    }
+    chatLog("Unknown command.", BY_SERVER);
+    chatLog("Type /help for a list of commands.", BY_SERVER);
 }
