@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: checkbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: checkbox.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "checkbox.h"
@@ -34,8 +34,8 @@ Image *CheckBox::checkBoxChecked;
 Image *CheckBox::checkBoxDisabled;
 Image *CheckBox::checkBoxDisabledChecked;
 
-CheckBox::CheckBox(const std::string& caption, bool marked):
-    gcn::CheckBox(caption, marked)
+CheckBox::CheckBox(const std::string& caption, bool selected):
+    gcn::CheckBox(caption, selected)
 {
     if (instances == 0)
     {
@@ -68,7 +68,7 @@ void CheckBox::drawBox(gcn::Graphics* graphics)
 {
     Image *box;
 
-    if (mMarked) {
+    if (isSelected()) {
         if (isEnabled()) {
             box = checkBoxChecked;
         } else {
