@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: gccontainer.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: gccontainer.h 4208 2008-04-29 11:25:26Z b_lindeijer $
  */
 
 #ifndef _TMW_GUI_GCCONTAINER_H
@@ -28,14 +28,18 @@
 
 #include <guichan/widgets/container.hpp>
 
+/**
+ * A garbage collecting container. Childs added to this container are
+ * automatically deleted when the container is deleted.
+ */
 class GCContainer : public gcn::Container
 {
     public:
         virtual ~GCContainer();
 
-        virtual void add(gcn::Widget *w, bool delChild = true);
+        virtual void add(gcn::Widget *w);
 
-        virtual void add(gcn::Widget *w, int x, int y, bool delChild = true);
+        virtual void add(gcn::Widget *w, int x, int y);
 
         virtual void death(const gcn::Event &event);
 
