@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: inventorywindow.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: inventorywindow.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "inventorywindow.h"
@@ -57,7 +57,7 @@ InventoryWindow::InventoryWindow():
     mUseButton = new Button("Use", "use", this);
     mDropButton = new Button("Drop", "drop", this);
 
-    mItems = new ItemContainer(player_node->mInventory);
+    mItems = new ItemContainer(player_node->getInventory());
     mItems->addSelectionListener(this);
 
     mInvenScroll = new ScrollArea(mItems);
@@ -81,7 +81,6 @@ InventoryWindow::InventoryWindow():
 
     mUseButton->setSize(60, mUseButton->getHeight());
 
-    addWindowListener(this);
     loadWindowState();
 }
 
@@ -101,11 +100,10 @@ void InventoryWindow::logic()
 
 void InventoryWindow::action(const gcn::ActionEvent &event)
 {
-    Item *item = mItems->getItem();
+    Item *item = mItems->getSelectedItem();
 
-    if (!item) {
+    if (!item)
         return;
-    }
 
     if (event.getId() == "use") {
         if (item->isEquipment()) {
@@ -132,9 +130,9 @@ void InventoryWindow::action(const gcn::ActionEvent &event)
     }
 }
 
-void InventoryWindow::selectionChanged(const SelectionEvent &event)
+void InventoryWindow::valueChanged(const gcn::SelectionEvent &event)
 {
-    Item *item = mItems->getItem();
+    const Item *item = mItems->getSelectedItem();
 
     // Update name, effect and description
     if (!item)
@@ -162,30 +160,26 @@ void InventoryWindow::mouseClicked(gcn::MouseEvent &event)
 
     if (event.getButton() == gcn::MouseEvent::RIGHT)
     {
-        Item *item = mItems->getItem();
+        Item *item = mItems->getSelectedItem();
 
         if (!item) return;
 
         /* Convert relative to the window coordinates to absolute screen
          * coordinates.
          */
-        int mx = event.getX() + getX();
-        int my = event.getY() + getY();
+        const int mx = event.getX() + getX();
+        const int my = event.getY() + getY();
         viewport->showPopup(mx, my, item);
     }
 }
 
-void InventoryWindow::windowResized(const WindowEvent &event)
+void InventoryWindow::widgetResized(const gcn::Event &event)
 {
-    gcn::Rectangle area = getChildrenArea();
-    int width = area.width;
-    int height = area.height;
-    int columns = width / 24;
+    Window::widgetResized(event);
 
-    if (columns < 1)
-    {
-        columns = 1;
-    }
+    const gcn::Rectangle &area = getChildrenArea();
+    const int width = area.width;
+    const int height = area.height;
 
     // Adjust widgets
     mUseButton->setPosition(8, height - 8 - mUseButton->getHeight());
@@ -213,11 +207,11 @@ void InventoryWindow::windowResized(const WindowEvent &event)
 
 void InventoryWindow::updateButtons()
 {
-    Item *item;
+    const Item *selectedItem = mItems->getSelectedItem();
 
-    if ((item = mItems->getItem()) && item->isEquipment())
+    if (selectedItem && selectedItem->isEquipment())
     {
-        if (item->isEquipped()) {
+        if (selectedItem->isEquipped()) {
             mUseButton->setCaption("Unequip");
         }
         else {
@@ -225,14 +219,14 @@ void InventoryWindow::updateButtons()
         }
     }
     else {
-        mUseButton ->setCaption("Use");
+        mUseButton->setCaption("Use");
     }
 
-    mUseButton->setEnabled(!!item);
-    mDropButton->setEnabled(!!item);
+    mUseButton->setEnabled(selectedItem != 0);
+    mDropButton->setEnabled(selectedItem != 0);
 }
 
-Item* InventoryWindow::getItem()
+Item* InventoryWindow::getSelectedItem() const
 {
-    return mItems->getItem();
+    return mItems->getSelectedItem();
 }
