@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: itemcontainer.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: itemcontainer.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_ITEMCONTAINER_H__
@@ -26,20 +26,25 @@
 
 #include <guichan/mouselistener.hpp>
 #include <guichan/widget.hpp>
+#include <guichan/widgetlistener.hpp>
 
 #include <list>
 
 class Image;
 class Inventory;
 class Item;
-class SelectionListener;
+
+namespace gcn {
+    class SelectionListener;
+}
 
 /**
  * An item container. Used to show items in inventory and trade dialog.
  *
  * \ingroup GUI
  */
-class ItemContainer : public gcn::Widget, public gcn::MouseListener
+class ItemContainer : public gcn::Widget, public gcn::MouseListener,
+    public gcn::WidgetListener
 {
     public:
         /**
@@ -63,10 +68,9 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
         void draw(gcn::Graphics *graphics);
 
         /**
-         * Sets the width of the container. This is used to determine the new
-         * height of the container.
+         * Called whenever the widget changes size.
          */
-        void setWidth(int width);
+        void widgetResized(const gcn::Event &event);
 
         /**
          * Handles mouse click.
@@ -76,7 +80,7 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
         /**
          * Returns the selected item.
          */
-        Item* getItem();
+        Item* getSelectedItem() const;
 
         /**
          * Sets selected item to NULL.
@@ -87,7 +91,7 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
          * Adds a listener to the list that's notified each time a change to
          * the selection occurs.
          */
-        void addSelectionListener(SelectionListener *listener)
+        void addSelectionListener(gcn::SelectionListener *listener)
         {
             mListeners.push_back(listener);
         }
@@ -96,7 +100,7 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
          * Removes a listener from the list that's notified each time a change
          * to the selection occurs.
          */
-        void removeSelectionListener(SelectionListener *listener)
+        void removeSelectionListener(gcn::SelectionListener *listener)
         {
             mListeners.remove(listener);
         }
@@ -107,10 +111,15 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
          */
         void setSelectedItem(Item *item);
 
+        /**
+         * Determine and set the height of the container.
+         */
+        void recalculateHeight();
+
         /**
          * Sends out selection events to the list of selection listeners.
          */
-        void fireSelectionChangedEvent();
+        void distributeValueChangedEvent();
 
         Inventory *mInventory;
         Image *mSelImg;
@@ -118,7 +127,10 @@ class ItemContainer : public gcn::Widget, public gcn::MouseListener
 
         int mMaxItems;
 
-        std::list<SelectionListener*> mListeners;
+        std::list<gcn::SelectionListener*> mListeners;
+
+        static const int gridWidth;
+        static const int gridHeight;
 };
 
 #endif
