@@ -18,13 +18,11 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: listbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: listbox.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "listbox.h"
 
-#include "selectionlistener.h"
-
 #include <guichan/font.hpp>
 #include <guichan/graphics.hpp>
 #include <guichan/listmodel.hpp>
@@ -61,13 +59,6 @@ void ListBox::draw(gcn::Graphics *graphics)
     }
 }
 
-void
-ListBox::setSelected(int selected)
-{
-    gcn::ListBox::setSelected(selected);
-    fireSelectionChangedEvent();
-}
-
 void
 ListBox::mouseDragged(gcn::MouseEvent &event)
 {
@@ -75,15 +66,3 @@ ListBox::mouseDragged(gcn::MouseEvent &event)
     // selection to be updated as is default in many GUIs.
     mousePressed(event);
 }
-
-void ListBox::fireSelectionChangedEvent()
-{
-    SelectionEvent event(this);
-    SelectionListeners::iterator i_end = mListeners.end();
-    SelectionListeners::iterator i;
-
-    for (i = mListeners.begin(); i != i_end; ++i)
-    {
-        (*i)->selectionChanged(event);
-    }
-}
