@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: login.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: login.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "login.h"
@@ -124,7 +124,7 @@ LoginDialog::action(const gcn::ActionEvent &event)
         mLoginData->hostname = mServerField->getText();
         mLoginData->username = mUserField->getText();
         mLoginData->password = mPassField->getText();
-        mLoginData->remember = mKeepCheck->isMarked();
+        mLoginData->remember = mKeepCheck->isSelected();
         mLoginData->registerLogin = false;
 
         mOkButton->setEnabled(false);
