@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: minimap.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: minimap.cpp 4116 2008-04-17 12:48:43Z peaveydk $
  */
 
 #include "minimap.h"
@@ -95,8 +95,12 @@ void Minimap::draw(gcn::Graphics *graphics)
                 graphics->setColor(gcn::Color(209, 52, 61));
                 break;
 
-            default:
+            case Being::NPC:
+                graphics->setColor(gcn::Color(255, 255, 0));
                 break;
+
+            default:
+                continue;
         }
 
         int offset = (dotSize - 1) / 2;
