@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: npc_text.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: npc_text.cpp 4096 2008-04-16 08:39:59Z b_lindeijer $
  */
 
 #include "npc_text.h"
@@ -34,7 +34,7 @@
 NpcTextDialog::NpcTextDialog():
     Window("NPC")
 {
-    mTextBox = new TextBox();
+    mTextBox = new TextBox;
     mTextBox->setEditable(false);
     gcn::ScrollArea *scrollArea = new ScrollArea(mTextBox);
     Button *okButton = new Button("OK", "ok", this);
@@ -55,15 +55,15 @@ NpcTextDialog::NpcTextDialog():
 }
 
 void
-NpcTextDialog::setText(const char *text)
+NpcTextDialog::setText(const std::string &text)
 {
-    mTextBox->setText(text);
+    mTextBox->setTextWrapped(text);
 }
 
 void
 NpcTextDialog::addText(const std::string &text)
 {
-    mTextBox->setText(mTextBox->getText() + text + "\n");
+    mTextBox->setTextWrapped(mTextBox->getText() + text + "\n");
 }
 
 void
