@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: npc_text.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: npc_text.h 4096 2008-04-16 08:39:59Z b_lindeijer $
  */
 
 #ifndef _TMW_NPC_TEXT_H
@@ -28,7 +28,8 @@
 #include <guichan/actionlistener.hpp>
 
 #include "window.h"
-#include "../guichanfwd.h"
+
+class TextBox;
 
 /**
  * The npc text dialog.
@@ -57,7 +58,7 @@ class NpcTextDialog : public Window, public gcn::ActionListener
          * @param string The new text.
          */
         void
-        setText(const char *string);
+        setText(const std::string &string);
 
         /**
          * Adds the text to the text shows in the dialog. Also adds a newline
@@ -69,7 +70,7 @@ class NpcTextDialog : public Window, public gcn::ActionListener
         addText(const std::string &string);
 
     private:
-        gcn::TextBox *mTextBox;
+        TextBox *mTextBox;
 };
 
 #endif
