@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: playerbox.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: playerbox.h 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #ifndef __TMW_PLAYERBOX_H__
@@ -64,7 +64,7 @@ class PlayerBox : public gcn::ScrollArea
         /**
          * Draws the background and border of the scroll area.
          */
-        void drawBorder(gcn::Graphics *graphics);
+        void drawFrame(gcn::Graphics *graphics);
 
     private:
         const Player *mPlayer;       /**< The character used for display */
