@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: sell.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: sell.cpp 4442 2008-07-23 17:23:30Z umperio $
  */
 
 #include "sell.h"
@@ -37,7 +37,6 @@
 #include "../npc.h"
 
 #include "../resources/iteminfo.h"
-#include "../resources/itemdb.h"
 
 #include "../net/messageout.h"
 #include "../net/protocol.h"
@@ -49,6 +48,7 @@ SellDialog::SellDialog(Network *network):
     mNetwork(network),
     mMaxItems(0), mAmountItems(0)
 {
+    setWindowName("Sell");
     setResizable(true);
     setMinWidth(260);
     setMinHeight(230);
@@ -97,7 +97,6 @@ SellDialog::SellDialog(Network *network):
     add(mSellButton);
     add(mQuitButton);
 
-    addWindowListener(this);
     loadWindowState();
     setLocationRelativeTo(getParent());
 }
@@ -118,22 +117,15 @@ void SellDialog::reset()
     updateButtonsAndLabels();
 }
 
-void SellDialog::addItem(Item *item, int price)
+void SellDialog::addItem(const Item *item, int price)
 {
     if (!item)
         return;
 
-    ITEM_SHOP item_shop;
+    mShopItems->addItem(
+            item->getInvIndex(), item->getId(),
+            item->getQuantity(), price);
 
-    item_shop.name = item->getInfo().getName()
-        + " (" + toString(price) + " GP)";
-    item_shop.price = price;
-    item_shop.index = item->getInvIndex();
-    item_shop.id = item->getId();
-    item_shop.quantity = item->getQuantity();
-    item_shop.image = item->getInfo().getImage();
-
-    mShopItems->push_back(item_shop);
     mShopItemList->adjustSize();
 }
 
@@ -179,12 +171,13 @@ void SellDialog::action(const gcn::ActionEvent &event)
         MessageOut outMsg(mNetwork);
         outMsg.writeInt16(CMSG_NPC_SELL_REQUEST);
         outMsg.writeInt16(8);
-        outMsg.writeInt16(mShopItems->at(selectedItem).index);
+        outMsg.writeInt16(mShopItems->at(selectedItem)->getInvIndex());
         outMsg.writeInt16(mAmountItems);
 
         mMaxItems -= mAmountItems;
-        mShopItems->getShop()->at(selectedItem).quantity = mMaxItems;
-        mPlayerMoney += (mAmountItems * mShopItems->at(selectedItem).price);
+        mShopItems->getShop()->at(selectedItem)->setQuantity(mMaxItems);
+        mPlayerMoney +=
+            mAmountItems * mShopItems->at(selectedItem)->getPrice();
         mAmountItems = 1;
 
         if (!mMaxItems)
@@ -193,6 +186,11 @@ void SellDialog::action(const gcn::ActionEvent &event)
             mShopItemList->setSelected(-1);
             mShopItems->getShop()->erase(
                     mShopItems->getShop()->begin() + selectedItem);
+
+            gcn::Rectangle scroll;
+            scroll.y = mShopItemList->getRowHeight() * (selectedItem + 1);
+            scroll.height = mShopItemList->getRowHeight();
+            mShopItemList->showPart(scroll);
         }
         else
         {
@@ -204,7 +202,7 @@ void SellDialog::action(const gcn::ActionEvent &event)
     }
 }
 
-void SellDialog::selectionChanged(const SelectionEvent &event)
+void SellDialog::valueChanged(const gcn::SelectionEvent &event)
 {
     // Reset amount of items and update labels
     mAmountItems = 1;
@@ -214,8 +212,10 @@ void SellDialog::selectionChanged(const SelectionEvent &event)
     mSlider->gcn::Slider::setScale(1, mMaxItems);
 }
 
-void SellDialog::windowResized(const WindowEvent &event)
+void SellDialog::widgetResized(const gcn::Event &event)
 {
+    Window::widgetResized(event);
+
     gcn::Rectangle area = getChildrenArea();
     int width = area.width;
     int height = area.height;
@@ -271,15 +271,15 @@ SellDialog::updateButtonsAndLabels()
 
     if (selectedItem > -1)
     {
-        mMaxItems = mShopItems->at(selectedItem).quantity;
+        mMaxItems = mShopItems->at(selectedItem)->getQuantity();
         if (mAmountItems > mMaxItems)
         {
             mAmountItems = mMaxItems;
         }
 
-        income = mAmountItems * mShopItems->at(selectedItem).price;
+        income = mAmountItems * mShopItems->at(selectedItem)->getPrice();
 
-        const ItemInfo &info = ItemDB::get(mShopItems->at(selectedItem).id);
+        const ItemInfo &info = mShopItems->at(selectedItem)->getInfo();
         mItemDescLabel->setCaption("Description: " + info.getDescription());
         mItemEffectLabel->setCaption("Effect: " + info.getEffect());
     }
