@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup.cpp 4306 2008-05-28 20:22:37Z crush_tmw $
  */
 
 #include <algorithm>
@@ -30,9 +30,11 @@
 #include "setup_joystick.h"
 #include "setup_video.h"
 #include "setup_keyboard.h"
+#include "setup_players.h"
 #include "tabbedcontainer.h"
 
 #include "../utils/dtor.h"
+#include <iostream>
 
 extern Window *statusWindow;
 extern Window *minimap;
@@ -46,8 +48,8 @@ Setup::Setup():
     Window("Setup")
 {
     setCloseButton(true);
-    int width = 250;
-    int height = 245;
+    int width = 310;
+    int height = 265;
     setContentSize(width, height);
 
     const char *buttonNames[] = {
@@ -62,7 +64,7 @@ Setup::Setup():
     }
 
     TabbedContainer *panel = new TabbedContainer();
-    panel->setDimension(gcn::Rectangle(5, 5, 250, 205));
+    panel->setDimension(gcn::Rectangle(5, 5, width, height - 40));
     panel->setOpaque(false);
 
     SetupTab *tab;
@@ -83,6 +85,10 @@ Setup::Setup():
     panel->addTab(tab, "Keyboard");
     mTabs.push_back(tab);
 
+    tab = new Setup_Players();
+    panel->addTab(tab, "Players");
+    mTabs.push_back(tab);
+
     add(panel);
 
     setLocationRelativeTo(getParent());
