@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup_video.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup_video.cpp 4338 2008-06-05 18:41:39Z crush_tmw $
  */
 
 #include "setup_video.h"
@@ -43,6 +43,7 @@
 #include "../graphics.h"
 #include "../log.h"
 #include "../main.h"
+#include "../particle.h"
 
 #include "../utils/tostring.h"
 
@@ -124,7 +125,10 @@ Setup_Video::Setup_Video():
     mScrollRadiusField(new TextField()),
     mOverlayDetail((int) config.getValue("OverlayDetail", 2)),
     mOverlayDetailSlider(new Slider(0, 2)),
-    mOverlayDetailField(new gcn::Label(""))
+    mOverlayDetailField(new gcn::Label("")),
+    mParticleDetail(3 - (int) config.getValue("particleEmitterSkip", 1)),
+    mParticleDetailSlider(new Slider(0, 3)),
+    mParticleDetailField(new gcn::Label(""))
 {
     setOpaque(false);
 
@@ -156,7 +160,7 @@ Setup_Video::Setup_Video():
     mFpsField->setEnabled(mFps > 0);
     mFpsSlider->setValue(mFps);
     mFpsSlider->setEnabled(mFps > 0);
-    mFpsCheckBox->setMarked(mFps > 0);
+    mFpsCheckBox->setSelected(mFps > 0);
 
     mCustomCursorCheckBox->setActionEventId("customcursor");
     mAlphaSlider->setActionEventId("guialpha");
@@ -168,6 +172,8 @@ Setup_Video::Setup_Video():
     mScrollLazinessField->setActionEventId("scrolllazinessfield");
     mOverlayDetailSlider->setActionEventId("overlaydetailslider");
     mOverlayDetailField->setActionEventId("overlaydetailfield");
+    mParticleDetailSlider->setActionEventId("particledetailslider");
+    mParticleDetailField->setActionEventId("particledetailfield");
 
     mCustomCursorCheckBox->addActionListener(this);
     mAlphaSlider->addActionListener(this);
@@ -180,6 +186,8 @@ Setup_Video::Setup_Video():
     mScrollLazinessField->addKeyListener(this);
     mOverlayDetailSlider->addActionListener(this);
     mOverlayDetailField->addKeyListener(this);
+    mParticleDetailSlider->addActionListener(this);
+    mParticleDetailField->addKeyListener(this);
 
     mScrollRadiusSlider->setDimension(gcn::Rectangle(10, 120, 75, 10));
     gcn::Label *scrollRadiusLabel = new gcn::Label("Scroll radius");
@@ -216,6 +224,28 @@ Setup_Video::Setup_Video():
     }
     mOverlayDetailSlider->setValue(mOverlayDetail);
 
+    mParticleDetailSlider->setDimension(gcn::Rectangle(10, 180, 75, 10));
+    gcn::Label *particleDetailLabel = new gcn::Label("Particle Detail");
+    particleDetailLabel->setPosition(90, 180);
+    mParticleDetailField->setPosition(180, 180);
+    mParticleDetailField->setWidth(60);
+    switch (mParticleDetail)
+    {
+        case 0:
+            mParticleDetailField->setCaption("low");
+            break;
+        case 1:
+            mParticleDetailField->setCaption("medium");
+            break;
+        case 2:
+            mParticleDetailField->setCaption("high");
+            break;
+        case 3:
+            mParticleDetailField->setCaption("max");
+            break;
+    }
+    mParticleDetailSlider->setValue(mParticleDetail);
+
     add(scrollArea);
     add(mFsCheckBox);
     add(mOpenGLCheckBox);
@@ -234,6 +264,9 @@ Setup_Video::Setup_Video():
     add(mOverlayDetailSlider);
     add(overlayDetailLabel);
     add(mOverlayDetailField);
+    add(mParticleDetailSlider);
+    add(particleDetailLabel);
+    add(mParticleDetailField);
 }
 
 Setup_Video::~Setup_Video()
@@ -244,7 +277,7 @@ Setup_Video::~Setup_Video()
 void Setup_Video::apply()
 {
     // Full screen changes
-    bool fullscreen = mFsCheckBox->isMarked();
+    bool fullscreen = mFsCheckBox->isSelected();
     if (fullscreen != (config.getValue("screen", 0) == 1))
     {
         // checks for opengl usage
@@ -271,9 +304,9 @@ void Setup_Video::apply()
     }
 
     // OpenGL change
-    if (mOpenGLCheckBox->isMarked() != mOpenGLEnabled)
+    if (mOpenGLCheckBox->isSelected() != mOpenGLEnabled)
     {
-        config.setValue("opengl", mOpenGLCheckBox->isMarked() ? 1 : 0);
+        config.setValue("opengl", mOpenGLCheckBox->isSelected() ? 1 : 0);
 
         // OpenGL can currently only be changed by restarting, notify user.
         new OkDialog("Changing OpenGL",
@@ -314,11 +347,12 @@ Setup_Video::updateSlider(gcn::Slider *slider, gcn::TextField *field,
 
 void Setup_Video::cancel()
 {
-    mFsCheckBox->setMarked(mFullScreenEnabled);
-    mOpenGLCheckBox->setMarked(mOpenGLEnabled);
-    mCustomCursorCheckBox->setMarked(mCustomCursorEnabled);
+    mFsCheckBox->setSelected(mFullScreenEnabled);
+    mOpenGLCheckBox->setSelected(mOpenGLEnabled);
+    mCustomCursorCheckBox->setSelected(mCustomCursorEnabled);
     mAlphaSlider->setValue(mOpacity);
     mOverlayDetailSlider->setValue(mOverlayDetail);
+    mParticleDetailSlider->setValue(mParticleDetail);
 
     mScrollRadiusField->setText(toString(mOriginalScrollRadius));
     mScrollLazinessField->setText(toString(mOriginalScrollLaziness));
@@ -340,7 +374,7 @@ void Setup_Video::action(const gcn::ActionEvent &event)
     else if (event.getId() == "customcursor")
     {
         config.setValue("customcursor",
-                mCustomCursorCheckBox->isMarked() ? 1 : 0);
+                mCustomCursorCheckBox->isSelected() ? 1 : 0);
     }
     else if (event.getId() == "fpslimitslider")
     {
@@ -376,9 +410,30 @@ void Setup_Video::action(const gcn::ActionEvent &event)
         }
         config.setValue("OverlayDetail", val);
     }
+    else if (event.getId() == "particledetailslider")
+    {
+        int val = (int) mParticleDetailSlider->getValue();
+        switch (val)
+        {
+            case 0:
+                mParticleDetailField->setCaption("low");
+                break;
+            case 1:
+                mParticleDetailField->setCaption("medium");
+                break;
+            case 2:
+                mParticleDetailField->setCaption("high");
+                break;
+            case 3:
+                mParticleDetailField->setCaption("max");
+                break;
+        }
+        config.setValue("particleEmitterSkip", 3 - val);
+        Particle::emitterSkip = 4 - val;
+    }
     else if (event.getId() == "fpslimitcheckbox")
     {
-        if (mFpsCheckBox->isMarked())
+        if (mFpsCheckBox->isSelected())
         {
             mFps = (int) mFpsSlider->getValue();
         }
