@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup_video.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup_video.h 4306 2008-05-28 20:22:37Z crush_tmw $
  */
 
 #ifndef _TMW_GUI_SETUP_VIDEO_H
@@ -78,6 +78,10 @@ class Setup_Video : public SetupTab, public gcn::ActionListener,
         gcn::Slider *mOverlayDetailSlider;
         gcn::Label *mOverlayDetailField;
 
+        int mParticleDetail;
+        gcn::Slider *mParticleDetailSlider;
+        gcn::Label *mParticleDetailField;
+
         void
         updateSliders(bool originalValues);
 
