@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: slider.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: slider.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "slider.h"
@@ -64,7 +64,7 @@ Slider::~Slider()
 void Slider::init()
 {
     int x, y, w, h,o1,o2;
-    setBorderSize(0);
+    setFrameSize(0);
 
     // Load resources
     if (mInstances == 0)
