@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: textbox.cpp 4096 2008-04-16 08:39:59Z b_lindeijer $
  */
 
 #include "textbox.h"
@@ -32,17 +32,10 @@ TextBox::TextBox():
     gcn::TextBox()
 {
     setOpaque(false);
-    setBorderSize(0);
+    setFrameSize(0);
 }
 
-TextBox::TextBox(const std::string& text):
-    gcn::TextBox(text)
-{
-    setOpaque(false);
-    setBorderSize(0);
-}
-
-void TextBox::setText(const std::string &text)
+void TextBox::setTextWrapped(const std::string &text)
 {
     // Make sure parent scroll area sets width of this widget
     if (getParent())
