@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textfield.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: textfield.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -40,7 +40,7 @@ ImageRect TextField::skin;
 TextField::TextField(const std::string& text):
     gcn::TextField(text)
 {
-    setBorderSize(2);
+    setFrameSize(2);
 
     if (instances == 0)
     {
@@ -93,10 +93,10 @@ void TextField::draw(gcn::Graphics *graphics)
     graphics->drawText(mText, 1 - mXScroll, 1);
 }
 
-void TextField::drawBorder(gcn::Graphics *graphics)
+void TextField::drawFrame(gcn::Graphics *graphics)
 {
     int w, h, bs;
-    bs = getBorderSize();
+    bs = getFrameSize();
     w = getWidth() + bs * 2;
     h = getHeight() + bs * 2;
 
