@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textfield.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: textfield.h 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #ifndef __TMW_TEXTFIELD_H__
@@ -53,7 +53,7 @@ class TextField : public gcn::TextField {
         /**
          * Draws the background and border.
          */
-        void drawBorder(gcn::Graphics *graphics);
+        void drawFrame(gcn::Graphics *graphics);
 
     private:
         static int instances;
