@@ -27,9 +27,9 @@
 #include <memory>
 
 #include <guichan/actionlistener.hpp>
+#include <guichan/selectionlistener.hpp>
 
 #include "window.h"
-#include "selectionlistener.h"
 
 #include "../guichanfwd.h"
 
@@ -44,7 +44,7 @@ class ScrollArea;
  *
  * \ingroup Interface
  */
-class TradeWindow : public Window, gcn::ActionListener, SelectionListener
+class TradeWindow : public Window, gcn::ActionListener, gcn::SelectionListener
 {
     public:
         /**
@@ -107,7 +107,7 @@ class TradeWindow : public Window, gcn::ActionListener, SelectionListener
          * Updates the labels and makes sure only one item is selected in
          * either my inventory or partner inventory.
          */
-        void selectionChanged(const SelectionEvent &event);
+        void valueChanged(const gcn::SelectionEvent &event);
 
         /**
          * Called when receiving actions from the widgets.
