@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: viewport.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: viewport.cpp 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #include "viewport.h"
@@ -48,6 +48,8 @@
 
 #include <cassert>
 
+extern volatile int tick_time;
+
 Viewport::Viewport():
     mMap(0),
     mPixelViewX(0.0f),
@@ -222,12 +224,8 @@ Viewport::draw(gcn::Graphics *gcnGraphics)
     // Draw tiles and sprites
     if (mMap)
     {
-        mMap->draw(graphics, (int) mPixelViewX, (int) mPixelViewY, 0);
-        drawTargetCursor(graphics);
-        mMap->draw(graphics, (int) mPixelViewX, (int) mPixelViewY, 1);
-        mMap->draw(graphics, (int) mPixelViewX, (int) mPixelViewY, 2);
-        mMap->drawOverlay(graphics, mPixelViewX, mPixelViewY,
-                (int) config.getValue("OverlayDetail", 2));
+        mMap->draw(graphics, (int) mPixelViewX, (int) mPixelViewY);
+        drawTargetCursor(graphics); // TODO: Draw the cursor with the sprite
         drawTargetName(graphics);
     }
 
@@ -259,7 +257,7 @@ Viewport::draw(gcn::Graphics *gcnGraphics)
         }
     }
 
-    // Draw player nickname, speech, and emotion sprite as needed
+    // Draw player names, speech, and emotion sprite as needed
     Beings &beings = beingManager->getAll();
     for (BeingIterator i = beings.begin(); i != beings.end(); i++)
     {
@@ -398,7 +396,10 @@ Viewport::mousePressed(gcn::MouseEvent &event)
         FloorItem *item;
 
         // Interact with some being
-        if ((being = beingManager->findBeing(tilex, tiley)))
+//      if ((being = beingManager->findBeing(tilex, tiley))
+        int x = (int)((float) event.getX() + mPixelViewX);
+        int y = (int)((float) event.getY() + mPixelViewY);
+        if ((being = beingManager->findBeingByPixel(x, y)))
         {
             switch (being->getType())
             {
@@ -411,7 +412,19 @@ Viewport::mousePressed(gcn::MouseEvent &event)
                     if (being->mAction == Being::DEAD)
                         break;
 
-                    player_node->attack(being, true);
+                    if (player_node->withinAttackRange(being))
+                    {
+                        player_node->attack(being, true);
+                    }
+                    else
+                    {
+                        Uint8 *keys = SDL_GetKeyState(NULL);
+                        if (!(keys[SDLK_LSHIFT] || keys[SDLK_RSHIFT]))
+                        {
+                            player_node->stopAttack();
+                            player_node->setGotoTarget(being);
+                        }
+                    }
                     break;
 
                 default:
