@@ -18,18 +18,17 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: window.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: window.h 4207 2008-04-29 09:10:43Z b_lindeijer $
  */
 
 #ifndef _TMW_WINDOW_H__
 #define _TMW_WINDOW_H__
 
 #include <guichan/widgets/window.hpp>
+#include <guichan/widgetlistener.hpp>
 
 #include "../guichanfwd.h"
 
-#include "windowlistener.h"
-
 class ConfigListener;
 class GCContainer;
 class ImageRect;
@@ -43,7 +42,7 @@ class Image;
  *
  * \ingroup GUI
  */
-class Window : public gcn::Window
+class Window : public gcn::Window, gcn::WidgetListener
 {
     public:
         friend class WindowConfigListener;
@@ -77,65 +76,22 @@ class Window : public gcn::Window
         void draw(gcn::Graphics *graphics);
 
         /**
-         * Adds a widget to the window.
+         * Adds a widget to the window. The widget will be deleted by the
+         * window.
          */
-        void add(gcn::Widget *wi, bool delChild = true);
+        void add(gcn::Widget *w);
 
         /**
-         * Adds a widget to the window and also specifices its position.
+         * Adds a widget to the window and also specifices its position. The
+         * widget will be deleted by the window.
          */
-        void add(gcn::Widget *w, int x, int y, bool delChild = true);
-
-        /**
-         * Sets the width of the window contents.
-         */
-        void setContentWidth(int width);
-
-        /**
-         * Sets the height of the window contents.
-         */
-        void setContentHeight(int height);
+        void add(gcn::Widget *w, int x, int y);
 
         /**
          * Sets the size of this window.
          */
         void setContentSize(int width, int height);
 
-        /**
-         * Sets the size of this window.
-         */
-        void setSize(int width, int height);
-
-        /**
-         * Sets the width of this window.
-         */
-        void setWidth(int width);
-
-        /**
-         * Sets the height of this window.
-         */
-        void setHeight(int height);
-
-        /**
-         * Sets the position and size of this window.
-         */
-        void setDimension(const gcn::Rectangle &dimension);
-
-        /**
-         * Sets the position of this window.
-         */
-        void setPosition(int x, int y);
-
-        /**
-         * Sets the window x coordinate.
-         */
-        void setX(int x);
-
-        /**
-         * Sets the window y coordinate.
-         */
-        void setY(int y);
-
         /**
          * Sets the location relative to the given widget.
          */
@@ -146,6 +102,11 @@ class Window : public gcn::Window
          */
         void setResizable(bool resize);
 
+        /**
+         * Called whenever the widget changes size.
+         */
+        void widgetResized(const gcn::Event &event);
+
         /**
          * Sets whether or not the window has a close button.
          */
@@ -276,20 +237,6 @@ class Window : public gcn::Window
          */
         virtual void resetToDefaultSize();
 
-        /**
-         * Adds a listener to the list that's notified when the window is
-         * moved or resized.
-         */
-        void addWindowListener(WindowListener *listener)
-        { mListeners.push_back(listener); }
-
-        /**
-         * Removes a listener from the list that's notified when the window is
-         * moved or resized.
-         */
-        void removeWindowListener(WindowListener *listener)
-        { mListeners.remove(listener); }
-
         enum ResizeHandles
         {
             TOP    = 0x01,
@@ -344,14 +291,6 @@ class Window : public gcn::Window
          * where two borders are moved at the same time.
          */
         static const int resizeBorderWidth = 10;
-
-    private:
-        /**
-         * Sends out a window event to the list of selection listeners.
-         */
-        void fireWindowEvent(const WindowEvent &event);
-
-        WindowListeners mListeners;
 };
 
 #endif
