@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: localplayer.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: localplayer.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "localplayer.h"
@@ -45,11 +45,12 @@ LocalPlayer::LocalPlayer(Uint32 id, Uint16 job, Map *map):
     Player(id, job, map),
     mXpForNextLevel(0),
     mAttackRange(0),
-    mInventory(new Inventory),
     mXp(0), mNetwork(0),
     mTarget(NULL), mPickUpTarget(NULL),
-    mTrading(false), mLastAction(-1),
-    mWalkingDir(0), mDestX(0), mDestY(0)
+    mTrading(false), mGoingToTarget(false),
+    mLastAction(-1),
+    mWalkingDir(0), mDestX(0), mDestY(0),
+    mInventory(new Inventory)
 {
 }
 
@@ -104,42 +105,26 @@ void LocalPlayer::nextStep()
         {
             walk(mWalkingDir);
         }
+
+    }
+
+    if (mGoingToTarget && mTarget && withinAttackRange(mTarget))
+    {
+        mAction = Being::STAND;
+        attack(mTarget, true);
+        mGoingToTarget = false;
+        mPath.clear();
+        return;
+    }
+    else if (mGoingToTarget && !mTarget)
+    {
+        mGoingToTarget = false;
+        mPath.clear();
     }
 
     Player::nextStep();
 }
 
-void LocalPlayer::clearInventory()
-{
-    mInventory->clear();
-}
-
-void LocalPlayer::addInvItem(int id, int quantity, bool equipment)
-{
-    mInventory->addItem(id, quantity, equipment);
-}
-
-void LocalPlayer::addInvItem(int index, int id, int quantity, bool equipment)
-{
-    mInventory->addItem(index, id, quantity, equipment);
-}
-
-Item* LocalPlayer::getInvItem(int index)
-{
-    return mInventory->getItem(index);
-}
-
-Item* LocalPlayer::searchForItem(int itemId)
-{
-    for (int i = 0; i < INVENTORY_SIZE; i++)
-    {
-        if (itemId == mInventory->getItem(i)->getId()) {
-            return mInventory->getItem(i);
-        }
-    }
-    return NULL;
-}
-
 void LocalPlayer::equipItem(Item *item)
 {
     MessageOut outMsg(mNetwork);
@@ -157,7 +142,7 @@ void LocalPlayer::unequipItem(Item *item)
     outMsg.writeInt16(CMSG_PLAYER_UNEQUIP);
     outMsg.writeInt16(item->getInvIndex());
 
-    // Tidy equipment directly to avoid weapon still shown bug, by instance
+    // Tidy equipment directly to avoid weapon still shown bug, for instance
     mEquipment->removeEquipment(item);
 }
 
@@ -453,3 +438,23 @@ void LocalPlayer::setXp(int xp)
     }
     mXp = xp;
 }
+
+bool LocalPlayer::withinAttackRange(Being *target)
+{
+    int dist_x = abs(target->mX - mX);
+    int dist_y = abs(target->mY - mY);
+
+    if (dist_x > getAttackRange() || dist_y > getAttackRange())
+    {
+        return false;
+    }
+
+    return true;
+}
+
+void LocalPlayer::setGotoTarget(Being *target)
+{
+    mTarget = target;
+    mGoingToTarget = true;
+    setDestination(target->mX, target->mY);
+}
