@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: localplayer.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: localplayer.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_LOCALPLAYER_H
@@ -70,18 +70,10 @@ class LocalPlayer : public Player
         virtual void
         drawName(Graphics *graphics, Sint32 offsetX, Sint32 offsetY) {};
 
-        void clearInventory();
-        void addInvItem(int id, int quantity, bool equipment);
-        void addInvItem(int index, int id, int quantity, bool equipment);
-        Item* getInvItem(int index);
-
         /**
-         * Searches for the specified item by it's identification.
-         *
-         * @param itemId The id of the item to be searched.
-         * @return Item found on success, NULL on failure.
+         * Returns the player's inventory.
          */
-        Item* searchForItem(int itemId);
+        Inventory* getInventory() const { return mInventory; }
 
         /**
          * Equips an item.
@@ -160,6 +152,16 @@ class LocalPlayer : public Player
          */
         void setWalkingDir(int dir);
 
+        /**
+         * Sets going to being to attack
+         */
+        void setGotoTarget(Being *target);
+
+        /**
+         * Returns whether the target is in range to attack
+         */
+        bool withinAttackRange(Being *target);
+
         void raiseAttribute(Attribute attr);
         void raiseSkill(Uint16 skillId);
 
@@ -203,8 +205,6 @@ class LocalPlayer : public Player
 
         float mLastAttackTime; /**< Used to synchronize the charge dialog */
 
-        Inventory *mInventory;
-
     protected:
         void walk(unsigned char dir);
 
@@ -215,10 +215,13 @@ class LocalPlayer : public Player
         FloorItem *mPickUpTarget;
 
         bool mTrading;
+        bool mGoingToTarget;
         int mLastAction;    /**< Time stamp of the last action, -1 if none. */
         int mWalkingDir;    /**< The direction the player is walking in. */
         int mDestX;         /**< X coordinate of destination. */
         int mDestY;         /**< Y coordinate of destination. */
+
+        Inventory *mInventory;
 };
 
 extern LocalPlayer *player_node;
