@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: main.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: main.cpp 4426 2008-07-17 23:08:17Z b_lindeijer $
  */
 
 #include "main.h"
@@ -46,9 +46,10 @@
 
 #include "configuration.h"
 #include "keyboardconfig.h"
+#include "player_relations.h"
 #include "game.h"
 #include "graphics.h"
-//#include "itemshortcut.h"
+#include "itemshortcut.h"
 #include "lockedarray.h"
 #include "localplayer.h"
 #include "log.h"
@@ -77,6 +78,7 @@
 #include "resources/image.h"
 #include "resources/itemdb.h"
 #include "resources/monsterdb.h"
+#include "resources/npcdb.h"
 #include "resources/resourcemanager.h"
 
 #include "utils/dtor.h"
@@ -86,8 +88,6 @@
 #include <SDL_syswm.h>
 #endif
 
-std::string homeDir;
-
 // Account infos
 char n_server, n_character;
 
@@ -108,6 +108,21 @@ Configuration config;         /**< XML file configuration reader */
 Logger *logger;               /**< Log object */
 KeyboardConfig keyboard;
 
+CharServerHandler charServerHandler;
+LoginData loginData;
+LockedArray<LocalPlayer*> charInfo(MAX_SLOT + 1);
+
+
+// This anonymous namespace hides whatever is inside from other modules.
+namespace {
+
+std::string homeDir;
+std::string updateHost;
+std::string updatesDir;
+
+LoginHandler loginHandler;
+MapLoginHandler mapLoginHandler;
+
 /**
  * A structure holding the values of various options that can be passed from
  * the command line.
@@ -132,8 +147,55 @@ struct Options
     std::string password;
     std::string playername;
     std::string configPath;
+    std::string updateHost;
 };
 
+/**
+ * Parse the update host and determine the updates directory
+ * Then verify that the directory exists (creating if needed).
+ */
+void setUpdatesDir()
+{
+    // If updatesHost is currently empty, fill it from config file
+    if (updateHost.empty()) {
+        updateHost =
+            config.getValue("updatehost", "http://updates.thanaworld.org");
+    }
+
+    // Remove any trailing slash at the end of the update host
+    if (updateHost.at(updateHost.size() - 1) == '/')
+        updateHost.resize(updateHost.size() - 1);
+
+    // Parse out any "http://" or "ftp://", and set the updates directory
+    size_t pos;
+    pos = updateHost.find("://");
+    if (pos != updateHost.npos) {
+        if (pos + 3 < updateHost.length()) {
+            updatesDir =
+                "updates/" + updateHost.substr(pos + 3);
+        } else {
+            logger->log("Error: Invalid update host: %s", updateHost.c_str());
+            errorMessage = "Invalid update host: " + updateHost;
+            state = ERROR_STATE;
+        }
+    } else {
+        logger->log("Warning: no protocol was specified for the update host");
+        updatesDir = "updates/" + updateHost;
+    }
+
+    ResourceManager *resman = ResourceManager::getInstance();
+
+    // Verify that the updates directory exists. Create if necessary.
+    if (!resman->isDirectory("/" + updatesDir)) {
+        if (!resman->mkdir("/" + updatesDir)) {
+            logger->log("Error: %s/%s can't be made, but doesn't exist!",
+                         homeDir.c_str(), updatesDir.c_str());
+            errorMessage = "Error creating updates directory!";
+            state = ERROR_STATE;
+        }
+    }
+}
+
 /**
  * Do all initialization stuff
  */
@@ -143,6 +205,12 @@ void init_engine(const Options &options)
 #if defined WIN32
     if (!CreateDirectory(homeDir.c_str(), 0) &&
             GetLastError() != ERROR_ALREADY_EXISTS)
+#elif defined __APPLE__
+    // Use Application Directory instead of .tmw
+    homeDir = std::string(PHYSFS_getUserDir()) + 
+        "/Library/Application Support/The Mana World";
+    if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
+            (errno != EEXIST))
 #else
     // Checking if /home/user/.tmw folder exists.
     if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
@@ -187,15 +255,6 @@ void init_engine(const Options &options)
 
     // Add the user's homedir to PhysicsFS search path
     resman->addToSearchPath(homeDir, false);
-    // Creating and checking the updates folder existence and rights.
-    if (!resman->isDirectory("/updates")) {
-        if (!resman->mkdir("/updates")) {
-            std::cout << homeDir << "/updates "
-                      << "can't be made, but it doesn't exist! Exiting."
-                      << std::endl;
-            exit(1);
-        }
-    }
 
     // Add the main data directory to our PhysicsFS search path
     resman->addToSearchPath("data", true);
@@ -240,9 +299,10 @@ void init_engine(const Options &options)
     // default options !
     FILE *tmwFile = 0;
     std::string configPath = options.configPath;
-    if (configPath == "") {
+
+    if (configPath.empty())
         configPath = homeDir + "/config.xml";
-    }
+
     tmwFile = fopen(configPath.c_str(), "r");
 
     // If we can't read it, it doesn't exist !
@@ -308,10 +368,10 @@ void init_engine(const Options &options)
     graphics->_beginDraw();
 
     // Initialize the item shortcuts.
-    //itemShortcut = new ItemShortcut();
+    itemShortcut = new ItemShortcut();
 
     gui = new Gui(graphics);
-    state = UPDATE_STATE; /**< Initial game state */
+    state = LOGIN_STATE; /**< Initial game state */
 
     // Initialize sound engine
     try {
@@ -331,13 +391,16 @@ void init_engine(const Options &options)
 
     // Initialize keyboard
     keyboard.init();
+
+    // Initialise player relations
+    player_relations.init();
 }
 
 /** Clear the engine */
 void exit_engine()
 {
     // Before config.write() since it writes the shortcuts to the config
-    //delete itemShortcut;
+    delete itemShortcut;
 
     config.write();
 
@@ -353,6 +416,7 @@ void exit_engine()
     // Unload XML databases
     ItemDB::unload();
     MonsterDB::unload();
+    NPCDB::unload();
 
     ResourceManager::deleteInstance();
     delete logger;
@@ -370,8 +434,8 @@ void printHelp()
         << "  -P --password   : Login with this password" << std::endl
         << "  -D --default    : Bypass the login process with default settings" << std::endl
         << "  -p --playername : Login with this player" << std::endl
-        << "  -C --configfile : Configuration file to use"
-        << std::endl;
+        << "  -C --configfile : Configuration file to use" << std::endl
+        << "  -H --updatehost : Use this update host" << std::endl;
 }
 
 void printVersion()
@@ -383,9 +447,10 @@ void printVersion()
              "(local build?, PACKAGE_VERSION is not defined)" << std::endl;
 #endif
 }
+
 void parseOptions(int argc, char *argv[], Options &options)
 {
-    const char *optstring = "hvuU:P:Dp:C:";
+    const char *optstring = "hvuU:P:Dp:C:H:";
 
     const struct option long_options[] = {
         { "help",       no_argument,       0, 'h' },
@@ -396,10 +461,12 @@ void parseOptions(int argc, char *argv[], Options &options)
         { "default",    no_argument,       0, 'D' },
         { "playername", required_argument, 0, 'p' },
         { "configfile", required_argument, 0, 'C' },
+        { "updatehost", required_argument, 0, 'H' },
         { 0 }
     };
 
     while (optind < argc) {
+
         int result = getopt_long(argc, argv, optstring, long_options, NULL);
 
         if (result == -1) {
@@ -432,17 +499,20 @@ void parseOptions(int argc, char *argv[], Options &options)
             case 'C':
                 options.configPath = optarg;
                 break;
+            case 'H':
+                options.updateHost = optarg;
+                break;
         }
     }
 }
 
 /**
- * Reads the file "updates/resources2.txt" and attempts to load each update
- * mentioned in it.
+ * Reads the file "{Updates Directory}/resources2.txt" and attempts to load
+ * each update mentioned in it.
  */
 void loadUpdates()
 {
-    const std::string updatesFile = "updates/resources2.txt";
+    const std::string updatesFile = "/" + updatesDir + "/resources2.txt";
     ResourceManager *resman = ResourceManager::getInstance();
     std::vector<std::string> lines = resman->loadTextFile(updatesFile);
 
@@ -451,25 +521,18 @@ void loadUpdates()
         std::stringstream line(lines[i]);
         std::string filename;
         line >> filename;
-        resman->addToSearchPath(homeDir + "/updates/" + filename, false);
+        resman->addToSearchPath(homeDir + "/" + updatesDir + "/"
+                                + filename, false);
     }
 }
 
-CharServerHandler charServerHandler;
-LoginData loginData;
-LoginHandler loginHandler;
-LockedArray<LocalPlayer*> charInfo(MAX_SLOT + 1);
-MapLoginHandler mapLoginHandler;
-
-namespace {
-    struct ErrorListener : public gcn::ActionListener
+struct ErrorListener : public gcn::ActionListener
+{
+    void action(const gcn::ActionEvent &event)
     {
-        void action(const gcn::ActionEvent &event)
-        {
-            state = loginData.registerLogin ? REGISTER_STATE : LOGIN_STATE;
-        }
-    } errorListener;
-}
+        state = loginData.registerLogin ? REGISTER_STATE : LOGIN_STATE;
+    }
+} errorListener;
 
 // TODO Find some nice place for these functions
 void accountLogin(Network *network, LoginData *loginData)
@@ -486,7 +549,14 @@ void accountLogin(Network *network, LoginData *loginData)
     outMsg.writeInt32(0); // client version
     outMsg.writeString(loginData->username, 24);
     outMsg.writeString(loginData->password, 24);
-    outMsg.writeInt8(0); // unknown
+
+    /*
+     * eAthena calls the last byte "client version 2", but it isn't used at
+     * at all. We're retasking it, with bit 0 to indicate whether the client
+     * can handle the 0x63 "update host" packet. Clients prior to 0.0.25 send
+     * 0 here.
+     */
+    outMsg.writeInt8(0x01);
 
     // Clear the password, avoids auto login when returning to login
     loginData->password = "";
@@ -555,6 +625,9 @@ void mapLogin(Network *network, LoginData *loginData)
     network->skip(4);
 }
 
+} // namespace
+
+
 /** Main */
 int main(int argc, char *argv[])
 {
@@ -590,13 +663,6 @@ int main(int argc, char *argv[])
 
     SDL_Event event;
 
-    if (options.skipUpdate && state != ERROR_STATE) {
-        state = LOADDATA_STATE;
-    }
-    else {
-        state = UPDATE_STATE;
-    }
-
     unsigned int oldstate = !state; // We start with a status change.
 
     Game *game = NULL;
@@ -738,7 +804,8 @@ int main(int argc, char *argv[])
                     // Load XML databases
                     ItemDB::load();
                     MonsterDB::load();
-                    state = LOGIN_STATE;
+                    NPCDB::load();
+                    state = CHAR_CONNECT_STATE;
                     break;
 
                 case LOGIN_STATE:
@@ -759,7 +826,12 @@ int main(int argc, char *argv[])
 
                 case CHAR_SERVER_STATE:
                     logger->log("State: CHAR_SERVER");
-                    currentDialog = new ServerSelectDialog(&loginData);
+                    {
+                        int nextState = (options.skipUpdate) ?
+                            LOADDATA_STATE : UPDATE_STATE;
+                        currentDialog = new ServerSelectDialog(&loginData,
+                                nextState);
+                    }
                     if (options.chooseDefault || options.playername != "") {
                         ((ServerSelectDialog*) currentDialog)->action(
                             gcn::ActionEvent(NULL, "ok"));
@@ -806,8 +878,16 @@ int main(int argc, char *argv[])
                     break;
 
                 case UPDATE_STATE:
+                    // Determine which source to use for the update host
+                    if (!options.updateHost.empty())
+                        updateHost = options.updateHost;
+                    else
+                        updateHost = loginData.updateHost;
+
+                    setUpdatesDir();
                     logger->log("State: UPDATE");
-                    currentDialog = new UpdaterWindow();
+                    currentDialog = new UpdaterWindow(updateHost,
+                            homeDir + "/" + updatesDir);
                     break;
 
                 case ERROR_STATE:
