@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: charserverhandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: charserverhandler.cpp 4330 2008-06-04 08:53:01Z b_lindeijer $
  */
 
 #include "charserverhandler.h"
@@ -208,7 +208,7 @@ LocalPlayer* CharServerHandler::readPlayerData(MessageIn &msg, int &slot)
     tempPlayer->mLevel = msg.readInt16();
     msg.readInt16();                       // skill point
     tempPlayer->setSprite(Being::BOTTOMCLOTHES_SPRITE, msg.readInt16()); // head bottom
-    msg.readInt16();                       // shield
+    tempPlayer->setSprite(Being::SHIELD_SPRITE, msg.readInt16()); 
     tempPlayer->setSprite(Being::HAT_SPRITE, msg.readInt16()); // head option top
     tempPlayer->setSprite(Being::TOPCLOTHES_SPRITE, msg.readInt16()); // head option mid
     int hairColor = msg.readInt16();
