@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: playerhandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: playerhandler.cpp 4190 2008-04-26 17:37:03Z peaveydk $
  */
 
 #include "playerhandler.h"
@@ -30,6 +30,7 @@
 #include "../localplayer.h"
 #include "../log.h"
 #include "../npc.h"
+#include "../utils/tostring.h"
 
 #include "../gui/buy.h"
 #include "../gui/chat.h"
@@ -208,8 +209,14 @@ void PlayerHandler::handleMessage(MessageIn *msg)
                 case 0x0002:
                     player_node->mJobXp = msg->readInt32();
                     break;
-                case 0x0014:
-                    player_node->mGp = msg->readInt32();
+                case 0x0014: {
+                        Uint32 curGp = player_node->mGp;
+                        player_node->mGp = msg->readInt32();
+                        if (player_node->mGp > curGp)
+                            chatWindow->chatLog("You picked up " +
+                                toString(player_node->mGp - curGp) + " GP",
+                                BY_SERVER);
+                    }
                     break;
                 case 0x0016:
                     player_node->mXpForNextLevel = msg->readInt32();
