@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: protocol.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: protocol.h 4425 2008-07-17 22:52:53Z b_lindeijer $
  */
 
 #ifndef _TMW_PROTOCOL_
@@ -26,6 +26,7 @@
 
 // Packets from server to client
 #define SMSG_LOGIN_SUCCESS           0x0073 /**< Contains starting location */
+#define SMSG_UPDATE_HOST             0x0063 /**< Custom update host packet */
 #define SMSG_PLAYER_UPDATE_1         0x01d8
 #define SMSG_PLAYER_UPDATE_2         0x01d9
 #define SMSG_PLAYER_MOVE             0x01da /**< A nearby player moves */
@@ -57,6 +58,7 @@
 #define SMSG_BEING_MOVE              0x007b /**< A nearby monster moves */
 #define SMSG_BEING_REMOVE            0x0080
 #define SMSG_BEING_CHANGE_LOOKS      0x00c3
+#define SMSG_BEING_CHANGE_LOOKS2     0x01d7 /**< Same as 0x00c3, but 16 bit ID */
 #define SMSG_BEING_LEVELUP           0x019b
 #define SMSG_BEING_EMOTION           0x00c0
 #define SMSG_BEING_ACTION            0x008a /**< Attack, sit, stand up, ... */
@@ -72,6 +74,8 @@
 #define SMSG_NPC_BUY_RESPONSE        0x00ca
 #define SMSG_NPC_SELL_RESPONSE       0x00cb
 #define SMSG_PLAYER_CHAT             0x008e /**< Player talks */
+#define SMSG_WHISPER                 0x0097 /**< Whisper Recieved */
+#define SMSG_WHISPER_RESPONSE        0x0098
 #define SMSG_GM_CHAT                 0x009a /**< GM announce */
 #define SMSG_WALK_RESPONSE           0x0087
 #define SMSG_TRADE_REQUEST           0x00e5 /**< Receiving a request to trade */
@@ -89,6 +93,7 @@
 #define CMSG_NPC_BUY_REQUEST         0x00c8
 #define CMSG_NPC_BUY_SELL_REQUEST    0x00c5
 #define CMSG_CHAT_MESSAGE            0x008c
+#define CMSG_CHAT_WHISPER            0x0096
 #define CMSG_NPC_LIST_CHOICE         0x00b8
 #define CMSG_NPC_NEXT_REQUEST        0x00b9
 #define CMSG_NPC_SELL_REQUEST        0x00c9
