@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tradehandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: tradehandler.cpp 4354 2008-06-17 16:52:44Z the_enemy $
  */
 
 #include "tradehandler.h"
@@ -26,8 +26,10 @@
 #include "messagein.h"
 #include "protocol.h"
 
+#include "../inventory.h"
 #include "../item.h"
 #include "../localplayer.h"
+#include "../player_relations.h"
 
 #include "../gui/chat.h"
 #include "../gui/confirm_dialog.h"
@@ -48,8 +50,7 @@ namespace {
     } listener;
 }
 
-TradeHandler::TradeHandler():
-    mAcceptTradeRequests(true)
+TradeHandler::TradeHandler()
 {
     static const Uint16 _messages[] = {
         SMSG_TRADE_REQUEST,
@@ -64,15 +65,6 @@ TradeHandler::TradeHandler():
     handledMessages = _messages;
 }
 
-void TradeHandler::setAcceptTradeRequests(bool acceptTradeRequests)
-{
-    mAcceptTradeRequests = acceptTradeRequests;
-    if (mAcceptTradeRequests) {
-        chatWindow->chatLog("Accepting incoming trade requests", BY_SERVER);
-    } else {
-        chatWindow->chatLog("Ignoring incoming trade requests", BY_SERVER);
-    }
-}
 
 void TradeHandler::handleMessage(MessageIn *msg)
 {
@@ -87,7 +79,7 @@ void TradeHandler::handleMessage(MessageIn *msg)
                 // special message about the player being occupied.
                 tradePartnerName = msg->readString(24);
 
-                if (mAcceptTradeRequests)
+                if (player_relations.hasPermission(tradePartnerName, PlayerRelation::TRADE))
                 {
                     if (!player_node->tradeRequestOk())
                     {
@@ -133,8 +125,12 @@ void TradeHandler::handleMessage(MessageIn *msg)
                     tradeWindow->setVisible(true);
                     break;
                 case 4: // Trade cancelled
-                    chatWindow->chatLog("Trade with " + tradePartnerName +
-                            " cancelled", BY_SERVER);
+                    if (player_relations.hasPermission(tradePartnerName,
+                                                       PlayerRelation::SPEECH_LOG))
+                        chatWindow->chatLog("Trade with " + tradePartnerName +
+                                            " cancelled", BY_SERVER);
+                    // otherwise ignore silently
+                                    
                     tradeWindow->setVisible(false);
                     player_node->setTrading(false);
                     break;
@@ -166,7 +162,13 @@ void TradeHandler::handleMessage(MessageIn *msg)
         case SMSG_TRADE_ITEM_ADD_RESPONSE:
             // Trade: New Item add response (was 0x00ea, now 01b1)
             {
-                Item *item = player_node->getInvItem(msg->readInt16());
+                const int index = msg->readInt16();
+                Item *item = player_node->getInventory()->getItem(index);
+                if (!item)
+                {
+                    tradeWindow->receivedOk(true);
+                    return;
+                }
                 Sint16 quantity = msg->readInt16();
 
                 switch (msg->readInt8())
