@@ -18,16 +18,18 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: npc.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: npc.cpp 4255 2008-05-21 21:44:27Z crush_tmw $
  */
 
 #include "npc.h"
 
 #include "animatedsprite.h"
 #include "graphics.h"
+#include "particle.h"
 
 #include "net/messageout.h"
 #include "net/protocol.h"
+#include "resources/npcdb.h"
 
 #include "gui/gui.h"
 
@@ -36,8 +38,30 @@ NPC *current_npc = 0;
 NPC::NPC(Uint32 id, Uint16 job, Map *map, Network *network):
     Being(id, job, map), mNetwork(network)
 {
-    mSprites[BASE_SPRITE] = AnimatedSprite::load("graphics/sprites/npc.xml",
-            job - 100);
+    NPCInfo info = NPCDB::get(job);
+
+    //setup NPC sprites
+    int c = BASE_SPRITE;
+    for (std::list<NPCsprite*>::const_iterator i = info.sprites.begin();
+         i != info.sprites.end();
+         i++)
+    {
+        if (c == VECTOREND_SPRITE) break;
+
+        std::string file = "graphics/sprites/" + (*i)->sprite;
+        int variant = (*i)->variant;
+        mSprites[c] = AnimatedSprite::load(file, variant);
+        c++;
+    }
+
+    //setup particle effects
+    for (std::list<std::string>::const_iterator i = info.particles.begin();
+         i != info.particles.end();
+         i++)
+    {
+        Particle *p = particleEngine->addEffect(*i, 0, 0);
+        this->controlParticle(p);
+    }
 }
 
 Being::Type
