@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: particle.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: particle.cpp 4362 2008-06-24 12:29:33Z crush_tmw $
  */
 
 #include <algorithm>
@@ -57,11 +57,13 @@ Particle::Particle(Map *map):
     mLifetimePast(0),
     mFadeOut(0),
     mFadeIn(0),
+    mAlpha(1.0f),
     mAutoDelete(true),
     mMap(map),
     mGravity(0.0f),
     mRandomnes(0),
     mBounce(0.0f),
+    mFollow(false),
     mTarget(NULL),
     mAcceleration(0.0f),
     mInvDieDistance(-1.0f),
@@ -77,7 +79,7 @@ Particle::setupEngine()
 {
     Particle::maxCount = (int)config.getValue("particleMaxCount", 3000);
     Particle::fastPhysics = (int)config.getValue("particleFastPhysics", 0);
-    Particle::emitterSkip = (int)config.getValue("particleEmitterSkip", 0) + 1;
+    Particle::emitterSkip = (int)config.getValue("particleEmitterSkip", 1) + 1;
     disableAutoDelete();
     logger->log("Particle engine set up");
 }
@@ -94,6 +96,8 @@ Particle::update()
         mAlive = false;
     }
 
+    Vector oldPos = mPos;
+
     if (mAlive)
     {
         //calculate particle movement
@@ -170,7 +174,7 @@ Particle::update()
         }
 
         // Update child emitters
-        if (mLifetimePast%Particle::emitterSkip == 0)
+        if ((mLifetimePast-1)%Particle::emitterSkip == 0)
         {
             for (   EmitterIterator e = mChildEmitters.begin();
                     e != mChildEmitters.end();
@@ -190,10 +194,19 @@ Particle::update()
         }
     }
 
+    Vector change = mPos - oldPos;
+
     // Update child particles
+
     for (ParticleIterator p = mChildParticles.begin();
          p != mChildParticles.end();)
     {
+        //move particle with its parent if desired
+        if ((*p)->doesFollow())
+        {
+            (*p)->moveBy(change);
+        }
+        //update particle
         if ((*p)->update())
         {
             p++;
@@ -217,35 +230,17 @@ Particle::addEffect(const std::string &particleEffectFile,
 {
     Particle *newParticle = NULL;
 
-    // XML parser initialisation stuff
-    int size;
-    ResourceManager *resman = ResourceManager::getInstance();
-    char *data = (char*) resman->loadFile(particleEffectFile.c_str(), size);
+    XML::Document doc(particleEffectFile);
+    xmlNodePtr rootNode = doc.rootNode();
 
-    if (!data) {
-        logger->log("Warning: Particle engine could not find %s !",
-                    particleEffectFile.c_str());
-        return NULL;
-    }
-
-    xmlDocPtr doc = xmlParseMemory(data, size);
-    free(data);
-
-    if (!doc) {
-        logger->log("Warning: Particle engine found syntax error in %s!",
-                    particleEffectFile.c_str());
-        return NULL;
-    }
-
-    xmlNodePtr rootNode = xmlDocGetRootElement(doc);
     if (!rootNode || !xmlStrEqual(rootNode->name, BAD_CAST "effect"))
     {
-        logger->log("Warning: %s is not a valid particle effect definition file!",
-                    particleEffectFile.c_str());
-        xmlFreeDoc(doc);
+        logger->log("Error loading particle: %s", particleEffectFile.c_str());
         return NULL;
     }
 
+    ResourceManager *resman = ResourceManager::getInstance();
+
     // Parse particles
     for_each_xml_child_node(effectChildNode, rootNode)
     {
@@ -302,8 +297,6 @@ Particle::addEffect(const std::string &particleEffectFile,
         mChildParticles.push_back(newParticle);
     }
 
-    xmlFreeDoc(doc);
-
     return newParticle;
 }
 
