@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: particle.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: particle.h 4362 2008-06-24 12:29:33Z crush_tmw $
  */
 
 #ifndef _PARTICLE_H
@@ -160,6 +160,10 @@ class Particle : public Sprite
         moveBy(float x, float y, float z)
         { mPos.x += x; mPos.y += y; mPos.z += z; }
 
+        void
+        moveBy (Vector change)
+        { mPos += change; }
+
         /**
          * Sets the time in game ticks until the particle is destroyed.
          */
@@ -183,6 +187,13 @@ class Particle : public Sprite
         setFadeIn(int fadeIn)
         { mFadeIn = fadeIn; }
 
+        /**
+         * Sets the alpha value of the particle
+         */
+        void
+        setAlpha(float alpha)
+        { mAlpha = alpha; }
+
         /**
          * Sets the sprite iterator of the particle on the current map to make
          * it easier to remove the particle from the map when it is destroyed.
@@ -227,6 +238,20 @@ class Particle : public Sprite
         setBounce(float bouncieness)
         { mBounce = bouncieness; }
 
+        /**
+         * Sets the flag if the particle is supposed to be moved by its parent
+         */
+        void
+        setFollow(bool follow)
+        { mFollow = follow; }
+
+        /**
+         * Gets the flag if the particle is supposed to be moved by its parent
+         */
+        bool
+        doesFollow()
+        { return mFollow; }
+
         /**
          * Makes the particle move toward another particle with a
          * given acceleration and momentum
@@ -265,6 +290,7 @@ class Particle : public Sprite
         int mLifetimePast;          /**< Age of the particle in game ticks*/
         int mFadeOut;               /**< Lifetime in game ticks left where fading out begins*/
         int mFadeIn;                /**< Age in game ticks where fading in is finished*/
+        float mAlpha;               /**< Opacity of the graphical representation of the particle */
 
     private:
         // generic properties
@@ -279,6 +305,7 @@ class Particle : public Sprite
         float mGravity;             /**< Downward acceleration in pixels per game-tick. */
         int mRandomnes;             /**< Ammount of random vector change */
         float mBounce;              /**< How much the particle bounces off when hitting the ground */
+        bool mFollow;               /**< is this particle moved when its parent particle moves? */
 
         // follow-point particles
         Particle *mTarget;          /**< The particle that attracts this particle*/
