@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: particleemitter.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: particleemitter.cpp 4362 2008-06-24 12:29:33Z crush_tmw $
  */
 
 #include "particleemitter.h"
@@ -54,6 +54,7 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
     mParticleGravity.set(0.0f);
     mParticleRandomnes.set(0);
     mParticleBounce.set(0.0f);
+    mParticleFollow = false;
     mParticleAcceleration.set(0.0f);
     mParticleDieDistance.set(-1.0f);
     mParticleMomentum.set(1.0f);
@@ -61,6 +62,7 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
     mParticleFadeOut.set(0);
     mParticleFadeIn.set(0);
     mOutput.set(1);
+    mParticleAlpha.set(1.0f);
 
     for_each_xml_child_node(propertyNode, emitterNode)
     {
@@ -153,6 +155,14 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
             {
                 mParticleFadeIn = readMinMax(propertyNode, 0);
             }
+            else if (name == "alpha")
+            {
+                mParticleAlpha = readMinMax(propertyNode, 1.0f);
+            }
+            else if (name == "follow-parent")
+            {
+                mParticleFollow = true;
+            }
             else
             {
                 logger->log("Particle Engine: Warning, unknown emitter property \"%s\"",
@@ -253,6 +263,7 @@ ParticleEmitter & ParticleEmitter::operator=(const ParticleEmitter &o)
     mParticleGravity = o.mParticleGravity;
     mParticleRandomnes = o.mParticleRandomnes;
     mParticleBounce = o.mParticleBounce;
+    mParticleFollow = o.mParticleFollow;
     mParticleTarget = o.mParticleTarget;
     mParticleAcceleration = o.mParticleAcceleration;
     mParticleDieDistance = o.mParticleDieDistance;
@@ -260,6 +271,7 @@ ParticleEmitter & ParticleEmitter::operator=(const ParticleEmitter &o)
     mParticleLifetime = o.mParticleLifetime;
     mParticleFadeOut = o.mParticleFadeOut;
     mParticleFadeIn = o.mParticleFadeIn;
+    mParticleAlpha = o.mParticleAlpha;
     mMap = o.mMap;
     mOutput = o.mOutput;
     mParticleImage = o.mParticleImage;
@@ -333,6 +345,7 @@ ParticleEmitter::createParticles()
         newParticle->setRandomnes(mParticleRandomnes.value());
         newParticle->setGravity(mParticleGravity.value());
         newParticle->setBounce(mParticleBounce.value());
+        newParticle->setFollow(mParticleFollow);
 
         newParticle->setDestination(mParticleTarget,
                                     mParticleAcceleration.value(),
@@ -343,6 +356,7 @@ ParticleEmitter::createParticles()
         newParticle->setLifetime(mParticleLifetime.value());
         newParticle->setFadeOut(mParticleFadeOut.value());
         newParticle->setFadeIn(mParticleFadeIn.value());
+        newParticle->setAlpha(mParticleAlpha.value());
 
         for (std::list<ParticleEmitter>::iterator i = mParticleChildEmitters.begin();
              i != mParticleChildEmitters.end();
