@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: particleemitter.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: particleemitter.h 4362 2008-06-24 12:29:33Z crush_tmw $
  */
 
 #ifndef _PARTICLEEMITTER_H
@@ -99,6 +99,7 @@ class ParticleEmitter
         MinMax<float> mParticleGravity;
         MinMax<int> mParticleRandomnes;
         MinMax<float> mParticleBounce;
+        bool mParticleFollow;
 
         /*
          * Properties of targeting particles:
@@ -119,10 +120,12 @@ class ParticleEmitter
 
         MinMax<int> mOutput;   /**< Number of particles spawned per update */
 
+        /*
+         * Graphical representation of the particle
+         */
         Image *mParticleImage; /**< Particle image, if used */
-
-        /** Filename of particle animation file */
-        Animation mParticleAnimation;
+        Animation mParticleAnimation; /**< Filename of particle animation file */
+        MinMax<float> mParticleAlpha; /**< Opacity of the graphical representation of the particles */
 
         /** List of emitters the spawned particles are equipped with */
         std::list<ParticleEmitter> mParticleChildEmitters;
