@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: player.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: player.cpp 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #include "player.h"
@@ -36,7 +36,8 @@
 #include "gui/gui.h"
 
 Player::Player(int id, int job, Map *map):
-    Being(id, job, map)
+    Being(id, job, map),
+    mDrawStrategy(NULL)
 {
 }
 
@@ -74,15 +75,37 @@ Player::getType() const
     return PLAYER;
 }
 
+
+void
+Player::setNameDrawStrategy(PlayerNameDrawStrategy *draw_strategy)
+{
+    if (mDrawStrategy)
+        delete mDrawStrategy;
+    mDrawStrategy = draw_strategy;
+}
+
+class
+DefaultPlayerNameDrawStrategy : public PlayerNameDrawStrategy
+{
+public:
+    virtual void draw(Player *player, Graphics *graphics, int px, int py)
+    {
+        graphics->setFont(speechFont);
+        graphics->setColor(gcn::Color(255, 255, 255));
+        graphics->drawText(player->getName(), px + 15, py + 30, gcn::Graphics::CENTER);
+    }
+};
+
 void
 Player::drawName(Graphics *graphics, int offsetX, int offsetY)
 {
     int px = mPx + offsetX;
     int py = mPy + offsetY;
 
-    graphics->setFont(speechFont);
-    graphics->setColor(gcn::Color(255, 255, 255));
-    graphics->drawText(mName, px + 15, py + 30, gcn::Graphics::CENTER);
+    if (mDrawStrategy)
+        mDrawStrategy->draw(this, graphics, px, py);
+    else
+        DefaultPlayerNameDrawStrategy().draw(this, graphics, px, py);
 }
 
 void Player::setGender(int gender)
