@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: player.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: player.h 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #ifndef _TMW_PLAYER_H
@@ -29,6 +29,19 @@
 class Graphics;
 class Map;
 
+class Player;
+
+class PlayerNameDrawStrategy
+{
+public:
+    virtual ~PlayerNameDrawStrategy(void) {}
+
+    /**
+     * Draw the player's name
+     */
+    virtual void draw(Player *p, Graphics *graphics, int px, int py) = 0;
+};
+
 /**
  * A player being. Players have their name drawn beneath them. This class also
  * implements player-specific loading of base sprite, hair sprite and equipment
@@ -68,6 +81,21 @@ class Player : public Being
          */
         virtual void
         setSprite(int slot, int id, std::string color = "");
+
+        /**
+         * Sets the strategy responsible for drawing the player's name
+         *
+         * \param draw_strategy A strategy describing how the player's name
+         * should be drawn, or NULL for default
+         */
+        virtual void
+        setNameDrawStrategy(PlayerNameDrawStrategy *draw_strategy);
+
+        virtual PlayerNameDrawStrategy *
+        getNameDrawStrategy(void) const { return mDrawStrategy; }
+
+    private:
+        PlayerNameDrawStrategy *mDrawStrategy;
 };
 
 #endif
