@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: imageset.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: imageset.cpp 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -50,11 +50,11 @@ ImageSet::~ImageSet()
 }
 
 Image*
-ImageSet::get(size_type i)
+ImageSet::get(size_type i) const
 {
     if (i >= mImages.size())
     {
-        logger->log("Warning: Sprite #%i does not exist in this image set", i);
+        logger->log("Warning: No sprite %d in this image set", (int) i);
         return NULL;
     }
     else
