@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: monsterdb.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: monsterdb.cpp 4255 2008-05-21 21:44:27Z crush_tmw $
  */
 
 #include <algorithm>
@@ -50,27 +50,12 @@ MonsterDB::load()
 
     logger->log("Initializing monster database...");
 
-    ResourceManager *resman = ResourceManager::getInstance();
-    int size;
-    char *data = (char*)resman->loadFile("monsters.xml", size);
+    XML::Document doc("monsters.xml");
+    xmlNodePtr rootNode = doc.rootNode();
 
-    if (!data)
-    {
-        logger->error("Monster Database: Could not find monsters.xml!");
-    }
-
-    xmlDocPtr doc = xmlParseMemory(data, size);
-    free(data);
-
-    if (!doc)
-    {
-        logger->error("Monster Database: Error while parsing monster database (monsters.xml)!");
-    }
-
-    xmlNodePtr rootNode = xmlDocGetRootElement(doc);
     if (!rootNode || !xmlStrEqual(rootNode->name, BAD_CAST "monsters"))
     {
-        logger->error("Monster Database: monster.xml is not a valid database file!");
+        logger->error("Monster Database: Error while loading monster.xml!");
     }
 
     //iterate <monster>s
@@ -152,16 +137,14 @@ MonsterDB::load()
         mMonsterInfos[XML::getProperty(monsterNode, "id", 0)] = currentInfo;
     }
 
-    xmlFreeDoc(doc);
-
     mLoaded = true;
 }
 
 void
 MonsterDB::unload()
 {
-    for_each (  mMonsterInfos.begin(), mMonsterInfos.end(),
-                make_dtor(mMonsterInfos));
+    for_each(mMonsterInfos.begin(), mMonsterInfos.end(),
+             make_dtor(mMonsterInfos));
     mMonsterInfos.clear();
 
     mLoaded = false;
@@ -169,7 +152,7 @@ MonsterDB::unload()
 
 
 const MonsterInfo&
-MonsterDB::get (int id)
+MonsterDB::get(int id)
 {
     MonsterInfoIterator i = mMonsterInfos.find(id);
 
