@@ -21,6 +21,8 @@
  *  $Id: monsterinfo.cpp 2650 2006-09-03 15:00:47Z b_lindeijer $
  */
 
+#include <algorithm>
+
 #include "monsterinfo.h"
 
 #include "../utils/dtor.h"
@@ -33,15 +35,15 @@ MonsterInfo::MonsterInfo():
 
 MonsterInfo::~MonsterInfo()
 {
-    //kill vectors in mSoundEffects
-    for_each (  mSounds.begin(), mSounds.end(),
-                make_dtor(mSounds));
+    // kill vectors in mSoundEffects
+    for_each (mSounds.begin(), mSounds.end(),
+              make_dtor(mSounds));
     mSounds.clear();
 }
 
 
 void
-MonsterInfo::addSound (SoundEvent event, std::string filename)
+MonsterInfo::addSound(MonsterSoundEvent event, std::string filename)
 {
     if (mSounds.find(event) == mSounds.end())
     {
@@ -53,9 +55,9 @@ MonsterInfo::addSound (SoundEvent event, std::string filename)
 
 
 std::string
-MonsterInfo::getSound (SoundEvent event) const
+MonsterInfo::getSound(MonsterSoundEvent event) const
 {
-    std::map<SoundEvent, std::vector<std::string>* >::const_iterator i;
+    std::map<MonsterSoundEvent, std::vector<std::string>* >::const_iterator i;
 
     i = mSounds.find(event);
 
@@ -68,3 +70,8 @@ MonsterInfo::getSound (SoundEvent event) const
         return i->second->at(rand()%i->second->size());
     }
 }
+
+void MonsterInfo::addParticleEffect(std::string filename)
+{
+    mParticleEffects.push_back(filename);
+}
