@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: spritedef.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: spritedef.cpp 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #include <set>
@@ -51,68 +51,27 @@ SpriteDef::getAction(SpriteAction action) const
 
 SpriteDef *SpriteDef::load(std::string const &animationFile, int variant)
 {
-    int size;
-    ResourceManager *resman = ResourceManager::getInstance();
-
     std::string::size_type pos = animationFile.find('|');
     std::string palettes;
     if (pos != std::string::npos)
         palettes = animationFile.substr(pos + 1);
 
-    char *data = (char*) resman->loadFile
-        (animationFile.substr(0, pos).c_str(), size);
+    XML::Document doc(animationFile.substr(0, pos));
+    xmlNodePtr rootNode = doc.rootNode();
 
-    if (!data && animationFile != "graphics/sprites/error.xml")
-    {
-        return load("graphics/sprites/error.xml", 0);
-    }
-
-    xmlDocPtr doc = xmlParseMemory(data, size);
-    free(data);
-
-    if (!doc)
-    {
-        logger->log("Error, failed to parse %s.", animationFile.c_str());
-        return NULL;
-    }
-
-    xmlNodePtr rootNode = xmlDocGetRootElement(doc);
     if (!rootNode || !xmlStrEqual(rootNode->name, BAD_CAST "sprite"))
     {
-        logger->log("Error, failed to parse %s.", animationFile.c_str());
-        xmlFreeDoc(doc);
-        return NULL;
-    }
+        logger->log("Error, failed to parse %s", animationFile.c_str());
 
-    // Get the variant
-    int variant_num = XML::getProperty(rootNode, "variants", 0);
-    int variant_offset = 0;
-
-    if (variant_num > 0 && variant < variant_num)
-    {
-        variant_offset = variant * XML::getProperty(rootNode, "variant_offset", 0);
+        if (animationFile != "graphics/sprites/error.xml") {
+            return load("graphics/sprites/error.xml", 0);
+        } else {
+            return NULL;
+        }
     }
 
     SpriteDef *def = new SpriteDef;
-
-    for_each_xml_child_node(node, rootNode)
-    {
-        if (xmlStrEqual(node->name, BAD_CAST "imageset"))
-        {
-            def->loadImageSet(node, palettes);
-        }
-        else if (xmlStrEqual(node->name, BAD_CAST "action"))
-        {
-            def->loadAction(node, variant_offset);
-        }
-        else if (xmlStrEqual(node->name, BAD_CAST "include"))
-        {
-            def->includeSprite(node);
-        }
-    }
-
-    xmlFreeDoc(doc);
-
+    def->loadSprite(rootNode, variant, palettes);
     def->substituteActions();
     return def;
 }
@@ -135,11 +94,47 @@ void SpriteDef::substituteActions()
     substituteAction(ACTION_DEAD, ACTION_HURT);
 }
 
+void SpriteDef::loadSprite(xmlNodePtr spriteNode, int variant,
+                           const std::string &palettes)
+{
+    // Get the variant
+    const int variantCount = XML::getProperty(spriteNode, "variants", 0);
+    int variant_offset = 0;
+
+    if (variantCount > 0 && variant < variantCount)
+    {
+        variant_offset =
+            variant * XML::getProperty(spriteNode, "variant_offset", 0);
+    }
+
+    for_each_xml_child_node(node, spriteNode)
+    {
+        if (xmlStrEqual(node->name, BAD_CAST "imageset"))
+        {
+            loadImageSet(node, palettes);
+        }
+        else if (xmlStrEqual(node->name, BAD_CAST "action"))
+        {
+            loadAction(node, variant_offset);
+        }
+        else if (xmlStrEqual(node->name, BAD_CAST "include"))
+        {
+            includeSprite(node);
+        }
+    }
+}
+
 void SpriteDef::loadImageSet(xmlNodePtr node, std::string const &palettes)
 {
-    int width = XML::getProperty(node, "width", 0);
-    int height = XML::getProperty(node, "height", 0);
-    std::string name = XML::getProperty(node, "name", "");
+    const std::string name = XML::getProperty(node, "name", "");
+
+    // We don't allow redefining image sets. This way, an included sprite
+    // definition will use the already loaded image set with the same name.
+    if (mImageSets.find(name) != mImageSets.end())
+        return;
+
+    const int width = XML::getProperty(node, "width", 0);
+    const int height = XML::getProperty(node, "height", 0);
     std::string imageSrc = XML::getProperty(node, "src", "");
     Dye::instantiate(imageSrc, palettes);
 
@@ -200,9 +195,9 @@ SpriteDef::loadAnimation(xmlNodePtr animationNode,
                          Action *action, ImageSet *imageSet,
                          int variant_offset)
 {
-    std::string directionName =
+    const std::string directionName =
         XML::getProperty(animationNode, "direction", "");
-    SpriteDirection directionType = makeSpriteDirection(directionName);
+    const SpriteDirection directionType = makeSpriteDirection(directionName);
 
     if (directionType == DIRECTION_INVALID)
     {
@@ -217,7 +212,7 @@ SpriteDef::loadAnimation(xmlNodePtr animationNode,
     // Get animation frames
     for_each_xml_child_node(frameNode, animationNode)
     {
-        int delay = XML::getProperty(frameNode, "delay", 0);
+        const int delay = XML::getProperty(frameNode, "delay", 0);
         int offsetX = XML::getProperty(frameNode, "offsetX", 0);
         int offsetY = XML::getProperty(frameNode, "offsetY", 0);
         offsetY -= imageSet->getHeight() - 32;
@@ -225,7 +220,7 @@ SpriteDef::loadAnimation(xmlNodePtr animationNode,
 
         if (xmlStrEqual(frameNode->name, BAD_CAST "frame"))
         {
-            int index = XML::getProperty(frameNode, "index", -1);
+            const int index = XML::getProperty(frameNode, "index", -1);
 
             if (index < 0)
             {
@@ -246,7 +241,7 @@ SpriteDef::loadAnimation(xmlNodePtr animationNode,
         else if (xmlStrEqual(frameNode->name, BAD_CAST "sequence"))
         {
             int start = XML::getProperty(frameNode, "start", -1);
-            int end = XML::getProperty(frameNode, "end", -1);
+            const int end = XML::getProperty(frameNode, "end", -1);
 
             if (start < 0 || end < 0)
             {
@@ -279,12 +274,23 @@ SpriteDef::loadAnimation(xmlNodePtr animationNode,
 void
 SpriteDef::includeSprite(xmlNodePtr includeNode)
 {
-    std::string filename = XML::getProperty(includeNode, "file", "");
-    ResourceManager *resman = ResourceManager::getInstance();
-    SpriteDef *sprite = resman->getSprite("graphics/sprites/" + filename);
+    // TODO: Perform circular dependency check, since it's easy to crash the
+    // client this way.
+    const std::string filename = XML::getProperty(includeNode, "file", "");
 
-    // TODO: Somehow implement actually including it
-    sprite->decRef();
+    if (filename.empty())
+        return;
+
+    XML::Document doc("graphics/sprites/" + filename);
+    xmlNodePtr rootNode = doc.rootNode();
+
+    if (!rootNode || !xmlStrEqual(rootNode->name, BAD_CAST "sprite"))
+    {
+        logger->log("Error, no sprite root node in %s", filename.c_str());
+        return;
+    }
+
+    loadSprite(rootNode, 0);
 }
 
 void
