@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tileset.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: tileset.h 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #ifndef _TMW_TILESET_H_
@@ -44,8 +44,7 @@ class Tileset : public ImageSet
         /**
          * Returns the first gid.
          */
-        int
-        getFirstGid()
+        int getFirstGid() const
         {
             return mFirstGid;
         }
