@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: xml.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: xml.h 4255 2008-05-21 21:44:27Z crush_tmw $
  */
 
 #ifndef _TMW_XML_H
@@ -33,6 +33,43 @@
  */
 namespace XML
 {
+    /**
+     * A helper class for parsing an XML document, which also cleans it up
+     * again (RAII).
+     */
+    class Document
+    {
+        public:
+            /**
+             * Constructor that attempts to load the given file through the
+             * resource manager. Logs errors.
+             */
+            Document(const std::string &filename);
+
+            /**
+             * Constructor that attempts to load an XML document from memory.
+             * Does not log errors.
+             *
+             * @param data the string to parse as XML
+             * @param size the length of the string in bytes
+             */
+            Document(const char *data, int size);
+
+            /**
+             * Destructor. Frees the loaded XML file.
+             */
+            ~Document();
+
+            /**
+             * Returns the root node of the document (or NULL if there was a
+             * load error).
+             */
+            xmlNodePtr rootNode();
+
+        private:
+            xmlDocPtr mDoc;
+    };
+
     /**
      * Gets an integer property from an xmlNodePtr.
      */
